@@ -202,7 +202,7 @@ gnomeicu_applet_menu (BonoboUIComponent *uic,
       }
     
     file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
-				      "gnome-gnomeicu.png", TRUE, NULL);
+				      "gnomeicu.png", TRUE, NULL);
     if (file != NULL)
       {
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
@@ -454,4 +454,5 @@ static const gchar *gnomeicu_applet_get_status_str (GnomeICUApplet *applet)
   case GNOMEICU_APPLET_STATUS_NOT_RUNNING:
     return _("GnomeICU not running");
   }
+  return NULL;
 }
