@@ -320,7 +320,7 @@ void org_aff_change( GtkWidget *widget, gpointer pointer )
 void birthday_change( GtkWidget *widget, gpointer pointer )
 {
   time_t birthday_t;
-  struct tm birthday_tm;
+  struct tm *birthday_tm;
   GDate *date;
   GDateYear year;
 #ifdef TRACE_FUNCTION
@@ -337,11 +337,14 @@ void birthday_change( GtkWidget *widget, gpointer pointer )
   }
 
   birthday_t = gnome_date_edit_get_time(GNOME_DATE_EDIT(widget));
-  birthday_tm = *localtime(&birthday_t);
+  birthday_tm = localtime(&birthday_t);
+  
+  if (!birthday_tm)
+    return;
 
-  g_date_subtract_years(date, birthday_tm.tm_year);
-  g_date_subtract_months(date, birthday_tm.tm_mon);
-  g_date_subtract_days(date, birthday_tm.tm_mday-1);
+  g_date_subtract_years(date, birthday_tm->tm_year);
+  g_date_subtract_months(date, birthday_tm->tm_mon);
+  g_date_subtract_days(date, birthday_tm->tm_mday-1);
 
   year = g_date_get_year(date);
   if ((year != G_DATE_BAD_YEAR) && (year >= 1900)) {
@@ -463,7 +466,7 @@ void password_entry_changed (GtkWidget *widget, gpointer p)
 
 void on_reload_button_clicked ( GtkWidget *widget, gpointer pointer )
 {
-    if (!is_connected(GTK_WINDOW (g_object_get_data (G_OBJECT (widget), "dlg")), _("You can not update your informations while being disconnected.")))
+    if (!is_connected(GTK_WINDOW (g_object_get_data (G_OBJECT (widget), "dlg")), _("You can not update your information while disconnected.")))
         return;
     v7_request_our_info(mainconnection);
 }
@@ -477,7 +480,7 @@ void on_save_button_clicked ( GtkWidget *widget, gpointer pointer )
 #endif
 
   window = g_object_get_data (G_OBJECT (widget), "dlg");
-  if (!is_connected(GTK_WINDOW (window), _("You can not save your informations while being disconnected.")))
+  if (!is_connected(GTK_WINDOW (window), _("You can not save your informations while disconnected.")))
     return;
 
   if (homeinfo_changed) {
@@ -702,7 +705,7 @@ static void workinfo_save()
 static void moreinfo_save()
 {
   time_t birthday_t;
-  struct tm birthday_tm;
+  struct tm *birthday_tm;
 
 #ifdef TRACE_FUNCTION
   g_print( "moreinfo_save\n" );
@@ -711,10 +714,13 @@ static void moreinfo_save()
   our_info->age = atoi( gtk_entry_get_text( GTK_ENTRY( glade_xml_get_widget (our_info_xml, "age_entry" ) ) ) );
   
   birthday_t = gnome_date_edit_get_time(GNOME_DATE_EDIT(glade_xml_get_widget (our_info_xml, "birthday_dateedit")));
-  birthday_tm = *localtime(&birthday_t);
-  our_info->birth_day = birthday_tm.tm_mday;
-  our_info->birth_month = birthday_tm.tm_mon + 1;
-  our_info->birth_year = birthday_tm.tm_year + 1900;
+  birthday_tm = localtime(&birthday_t);
+
+  if (birthday_tm) {
+    our_info->birth_day = birthday_tm->tm_mday;
+    our_info->birth_month = birthday_tm->tm_mon + 1;
+    our_info->birth_year = birthday_tm->tm_year + 1900;
+  }
 
   if( !strcmp( gtk_entry_get_text( GTK_ENTRY( glade_xml_get_widget (our_info_xml, "sex_combo_entry"))), _("Male")))
     our_info->sex = MALE;
