@@ -27,7 +27,12 @@
 #undef MAX
 
 
-typedef struct
+/* This is because I am lazy */
+
+#define n_(String1, String2, n) dngettext (GETTEXT_PACKAGE, String1, String2, n)
+
+
+typedef struct toggles_t
 {
 	gboolean auto_popup;
 	gboolean full_reply;
@@ -66,7 +71,7 @@ typedef struct
 	gboolean default_to_chat;
 } _toggles;
 
-typedef struct 
+typedef struct programs_t
 {
 	gchar *receive_message;
 	gchar *receive_url;
@@ -104,6 +109,7 @@ typedef struct
 #define STATUS_DND_MAC         0x02
 #define STATUS_AIM_ONLINE      0x1000
 #define STATUS_AIM_AWAY        0x3000
+#define STATUS_CUSTOM          0x5000
 
 #define USER_ADDED_MESS        0x000c
 #define AUTH_REQ_MESS          0x0006
@@ -116,7 +122,7 @@ typedef struct
 #define MRCONTACT_MESS         0x8013
 #define AUTH_MESS              0x0008
 
-typedef struct
+typedef struct USER_INFO_T
 {
 	UIN_T uin;       /*General*/
 	gchar *nick;     /*General*/
@@ -178,11 +184,11 @@ typedef enum
 	MESSAGE_CHAT_REQ,    /* Request to start a chat */
 	MESSAGE_AUTH_REQ,    /* Request for authorization */
 	MESSAGE_USER_ADD,    /* User has added you to his/her list */
-	MESSAGE_USER_AUTHD,  /* User has authorized you to add him/her */
+	MESSAGE_USER_AUTHD,  /* User has authorized/denied you to add him/her */
 	MESSAGE_CONT_LIST    /* Received contact list */
 } MESSAGE_TYPES;
 
-typedef struct
+typedef struct stored_message_t
 {
 	MESSAGE_TYPES type;
 	time_t time;
@@ -196,7 +202,7 @@ typedef enum {
   INCOMING
 } tcp_conn;
 
-typedef struct
+typedef struct Contact_Member_t
 {
 	UIN_T uin;
 	DWORD status;
@@ -238,6 +244,9 @@ typedef struct
 	WORD vislist_uid;
 	WORD invlist_uid;
 	WORD ignorelist_uid;
+	time_t last_seen;
+	WORD idletime;
+	DWORD online_since, member_since, idle_since;
 	gboolean wait_auth; /* whether we need auth grant from this contact */
 	GSList *file_xfers;
 	gint newmsg_blink_timeout;
@@ -247,8 +256,6 @@ typedef struct
 {
   WORD gid;
   gchar *name;
-  gint total_user;
-  gint online_user;
 } GroupInfo;
 
 /* This is so much used overall, it is easier to provide a macro */
