@@ -14,8 +14,6 @@ typedef enum
   EV_MSGRECV,   /* Message received */
   EV_USERON,    /* User logon */
   EV_USEROFF,   /* User logoff */
-  EV_CHATREQ,   /* Chat request received */
-  EV_CHATBEEP,  /* Chat beep */
   EV_URLRECV,   /* URL received */
   EV_AUTHREQ,   /* Request for authorization received */
   EV_AUTH,      /* Authorize notification */
@@ -24,7 +22,6 @@ typedef enum
   EV_CONTLIST   /* Received Contact List */
 } ICQEvType;
 
-void gnomeicu_event( ICQEvType event, UIN_T uin );
-void gnomeicu_fire_external_program( ICQEvType event, CONTACT_PTR contact );
+void gnomeicu_event( ICQEvType event, GSList *contact );
 
 #endif /* __ICQ_EVENTS_H__ */
