@@ -422,8 +422,10 @@ void app_init (void)
         gint window_w, window_h;
 
 	MainData->xml = gicu_util_open_glade_xml ("main.glade", "app");
-	if (MainData->xml == NULL)
+	if (MainData->xml == NULL) {
+		g_error("Could not open main.glade");
 		exit(1);
+	}
 	
 	app_win = glade_xml_get_widget (MainData->xml, "app");
 
