@@ -85,19 +85,18 @@ void groups_add (const gchar *name, WORD gid)
   GroupInfo *ginfo;
 
   if (groups_name_by_gid (gid))
-    return; /* we don't want duplicate groups */ /* TEMP FIX */
+    return; /* we don't want duplicate groups */ /* FIXME */
 
   ginfo = g_new0(GroupInfo, 1);
 
   ginfo->gid = gid;
   if (name)
-	  ginfo->name = g_strdup(name);
+    ginfo->name = g_strdup(name);
   else
     ginfo->name = g_strdup (_("ERROR"));
 
-  gnomeicu_tree_add_group (ginfo);
-
   Groups = g_slist_append(Groups, ginfo);
+  gnomeicu_tree_group_add (ginfo);
 }
 
 /*
@@ -113,13 +112,13 @@ void groups_remove(WORD gid)
   if (ginfo == NULL)
     return;
   
-  gnomeicu_tree_remove_group(ginfo->data);
+  gnomeicu_tree_group_remove (ginfo->data);
 
   g_free(((GroupInfo *)ginfo->data)->name);
 
-  Groups = g_slist_remove(Groups, ginfo->data);
-
   g_free(ginfo->data);
+
+  Groups = g_slist_delete_link(Groups, ginfo);
 }
 
 gchar *groups_name_by_gid(WORD gid)
@@ -149,7 +148,7 @@ void groups_rename_by_gid (WORD gid, const gchar *name)
       ((GroupInfo *)ginfo->data)->name = g_strdup (name);
       break;
     }
-  gnomeicu_tree_rename_group(ginfo->data);
+  gnomeicu_tree_group_rename (ginfo->data);
 }
 
 guint groups_find_gid_by_name (const gchar *name)
