@@ -162,7 +162,7 @@ grpmgr_newgrp_clicked (GtkWidget *w, GtkEntry *entry)
   GtkTreeModel *model = NULL;
   GtkTreeIter iter;
 
-  if (!is_connected(GTK_WINDOW(g_object_get_data (G_OBJECT (w), "dlg")), _("You can not create a group while being disconnected.")))
+  if (!is_connected(GTK_WINDOW(g_object_get_data (G_OBJECT (w), "dlg")), _("You can not create a group while disconnected.")))
     return;
   gid = groups_gen_gid ();
   groups_add (gtk_entry_get_text (entry), gid);
@@ -238,7 +238,7 @@ grpmgr_delgrp_clicked (GtkWidget *w, GroupInfo *sel_grp)
     }
 
   if (!is_connected(GTK_WINDOW(g_object_get_data (G_OBJECT (w), "dlg")),
-                    _("You can not remove a group while being disconnected.")))
+                    _("You can not remove a group while disconnected.")))
     return;
 
   /* delete the group */
@@ -275,7 +275,7 @@ grpmgr_rename_button_clicked (GtkWidget *w, GtkTreeView *treeview)
   GtkTreeIter iter;
   GtkTreePath *path;
 
-  if (!is_connected(GTK_WINDOW(g_object_get_data (G_OBJECT (w), "dlg")), _("You can not rename a group while being disconnected.")))
+  if (!is_connected(GTK_WINDOW(g_object_get_data (G_OBJECT (w), "dlg")), _("You can not rename a group while disconnected.")))
     return;
 
   model = gtk_tree_view_get_model(treeview);
@@ -363,7 +363,7 @@ void grpmgr_rename (GtkWidget *widget, gchar *path_string, gchar *new_text,
   GtkTreeIter iter;
   gint gid;
 
-  if (!is_connected(GTK_WINDOW(g_object_get_data (G_OBJECT (store), "dlg")), _("You can not rename a group while being disconnected.")))
+  if (!is_connected(GTK_WINDOW(g_object_get_data (G_OBJECT (store), "dlg")), _("You can not rename a group while disconnected.")))
     return;
 
 
