@@ -22,9 +22,12 @@
 #include "util.h"
 #include "v7login.h"
 #include "v7send.h"
+#include "v7snac13.h"
 #include "groups.h"
 #include "group_popup.h"
 #include "auto_respond.h"
+#include "auth.h"
+#include "newsignup.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
@@ -55,7 +58,7 @@ static void del_file( GtkWidget *widget, gpointer data );
 /* static void open_dir( GtkWidget *widget, gpointer data ); */
 
 static void icq_user_added_you_msgbox(GSList *contact);
-static void icq_user_authorized_you_msgbox(GSList *contact);
+static void icq_user_authorized_you_msgbox(STORED_MESSAGE_PTR message_text, GSList *contact);
 static void icq_filetransfer_window(STORED_MESSAGE_PTR message_text,
 				    GSList* contact);
 static void icq_authorization_request_window(STORED_MESSAGE_PTR message_text,
@@ -73,6 +76,7 @@ static void icq_user_added_you_msgbox(GSList *contact)
 {
 	GtkWidget *dialog;
 	gchar* sender;
+	gint result;
 
 	g_assert(contact != NULL);
 
@@ -93,29 +97,117 @@ static void icq_user_added_you_msgbox(GSList *contact)
 	}
 
 	dialog = gtk_message_dialog_new (NULL, 0,
-	                                 GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+	                                 GTK_MESSAGE_INFO, GTK_BUTTONS_NONE,
 	                                 sender);
-	gtk_widget_show (dialog);
-	g_signal_connect (G_OBJECT (dialog), "response",
-	                  G_CALLBACK (gtk_widget_destroy), NULL);
+
+	if (!kontakt->inlist)
+	  gtk_dialog_add_button(GTK_DIALOG(dialog), _("Add User"), 1);
+	
+	gtk_dialog_add_button(GTK_DIALOG(dialog),
+			      GTK_STOCK_OK ,GTK_RESPONSE_OK);
+	
+	result = gtk_dialog_run(GTK_DIALOG(dialog));
+	
+	if (result == 1 && 
+	    is_connected(GTK_WINDOW(dialog),
+			 _("You can not add a contact while disconnected."))) {
+	  GtkWidget *adduser_dialog;
+	  GtkWidget *label, *option, *menu, *box;
+	  gchar *str;
+	  GSList *g;
+
+	  adduser_dialog = gtk_dialog_new_with_buttons (_("Pick a Group"),
+							GTK_WINDOW (dialog),
+							GTK_DIALOG_DESTROY_WITH_PARENT,
+							GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+							GTK_STOCK_OK, GTK_RESPONSE_OK,
+							NULL);
+
+	  gtk_container_set_border_width(GTK_CONTAINER(adduser_dialog), 6);
+	  gtk_box_set_spacing(GTK_BOX(GTK_DIALOG (adduser_dialog)->vbox), 12);
+
+	  box = gtk_hbox_new (FALSE, 12);
+	  gtk_container_set_border_width(GTK_CONTAINER(box), 6);
+	  
+	  gtk_container_add (GTK_CONTAINER (GTK_DIALOG (adduser_dialog)->vbox), box);
+
+	  label = gtk_label_new (_("Pick a group for this user:"));
+	  gtk_box_pack_start (GTK_BOX (box), label, FALSE, FALSE, 0);
+
+	  option = gtk_option_menu_new ();
+	  gtk_box_pack_start (GTK_BOX (box), option, FALSE, FALSE, 0);
+	  menu = gtk_menu_new ();
+
+	  for (g = Groups; g != NULL; g = g->next) {
+	    label = gtk_menu_item_new_with_label (((GroupInfo *)g->data)->name);
+	    g_object_set_data (G_OBJECT (label), "gid",
+			       GUINT_TO_POINTER ((guint)((GroupInfo *)g->data)->gid));
+	    gtk_menu_shell_append (GTK_MENU_SHELL (menu), label);
+	  }
+
+	  gtk_option_menu_set_menu (GTK_OPTION_MENU (option), menu);
+	  gtk_option_menu_set_history (GTK_OPTION_MENU (option), 0);
+
+	  gtk_widget_show_all (adduser_dialog);
+
+	  result = gtk_dialog_run(GTK_DIALOG(adduser_dialog));
+
+	  if ( result  == GTK_RESPONSE_OK  &&
+	       is_connected(GTK_WINDOW(adduser_dialog),
+			    _("You can not add a contact while disconnected."))) {
+	    GList *item;
+	    guint gid;
+
+	    item = g_list_nth (GTK_MENU_SHELL (menu)->children,
+			       gtk_option_menu_get_history (GTK_OPTION_MENU (option)));
+	    gid = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (item->data),
+						       "gid"));
+	    v7_try_add_uin (mainconnection, kontakt->uin, kontakt->nick, 
+			    gid, FALSE);
+	  }
+
+	  gtk_widget_destroy(adduser_dialog);
+	    
+	}
+
+	gtk_widget_destroy(dialog);
 
 	g_free(sender);
 }
 
 
-static void icq_user_authorized_you_msgbox(GSList *contact)
+static void icq_user_authorized_you_msgbox(STORED_MESSAGE_PTR message_text, GSList *contact)
 {
 	GtkWidget *dialog;
 
 	g_assert(contact != NULL);
-	dialog = gtk_message_dialog_new (GTK_WINDOW (MainData->window),
-	                                 GTK_DIALOG_DESTROY_WITH_PARENT,
-	                                 GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
-	                                 _("You are authorized to add %s to your list"),
-	                                 kontakt->nick);
-	gtk_widget_show (dialog);
+	if (message_text->data) {
+	  dialog = gtk_message_dialog_new (GTK_WINDOW (MainData->window),
+					   GTK_DIALOG_DESTROY_WITH_PARENT,
+					   GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+					   _("You are authorized to add %s to your list"),
+					   kontakt->nick);
+	} else {
+	  dialog = gtk_message_dialog_new (GTK_WINDOW (MainData->window),
+					   GTK_DIALOG_DESTROY_WITH_PARENT,
+					   GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
+					   _("You are NOT authorized to add %s to your list"),
+					   kontakt->nick);
+	}
+
+	if (message_text->message) {
+	  g_print(message_text->message);
+	  gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(dialog),
+						   "%s", 
+						   message_text->message);
+	}
+
+
 	g_signal_connect (G_OBJECT (dialog), "response",
 	                  G_CALLBACK (gtk_widget_destroy), NULL);
+
+	gtk_widget_show (dialog);
+
 }
 
 
@@ -408,7 +500,7 @@ void icq_msgbox( STORED_MESSAGE_PTR message_text, UIN_T uin )
 
 	case MESSAGE_USER_AUTHD:
 		/*** Sender has authorized you to add him to your list ***/
-		icq_user_authorized_you_msgbox(contact);
+		icq_user_authorized_you_msgbox(message_text, contact);
 		break;
 
 	case MESSAGE_CHAT_REQ:
@@ -433,127 +525,6 @@ void icq_msgbox( STORED_MESSAGE_PTR message_text, UIN_T uin )
 	}	       
 }
 
-GtkWidget *create_menu ( void )
-{
-	GtkWidget *item;
-	GtkWidget *menu;
-
-#ifdef TRACE_FUNCTION
-	g_print( "create_menu\n" );
-#endif
-
-	menu = gtk_menu_new();
-
-	item = gtk_menu_item_new_with_label ( _("Online") );
-
-	gtk_menu_shell_append( GTK_MENU_SHELL( menu ), item );
-	gtk_widget_show( item );
-
-	g_signal_connect( G_OBJECT( item ), "activate",
-	                  G_CALLBACK( icq_set_status_online ), NULL );
-
-	item = gtk_menu_item_new_with_label ( _("Offline") );
-
-	gtk_menu_shell_append( GTK_MENU_SHELL( menu ), item );
-	gtk_widget_show( item );
-
-	g_signal_connect( G_OBJECT( item ), "activate",
-	                  G_CALLBACK( icq_set_status_offline ), NULL );
-
-	item = gtk_menu_item_new_with_label ( _("Away") );
-
-	gtk_menu_shell_append( GTK_MENU_SHELL( menu ), item );
-	gtk_widget_show( item );
-
-	g_signal_connect( G_OBJECT( item ), "activate",
-	                  G_CALLBACK( icq_set_status_away ), NULL );
-
-	item = gtk_menu_item_new_with_label ( _("Not Available") );
-
-	gtk_menu_shell_append( GTK_MENU_SHELL( menu ), item );
-	gtk_widget_show( item );
-
-	g_signal_connect( G_OBJECT( item ), "activate",
-	                  G_CALLBACK( icq_set_status_na ), NULL );
-
-	item = gtk_menu_item_new_with_label ( _("Free for Chat") );
-
-	gtk_menu_shell_append( GTK_MENU_SHELL( menu ), item );
-	gtk_widget_show( item );
-
-	g_signal_connect( G_OBJECT( item ), "activate",
-	                  G_CALLBACK( icq_set_status_ffc ), NULL );
-
-	item = gtk_menu_item_new_with_label ( _("Occupied") );
-
-	gtk_menu_shell_append( GTK_MENU_SHELL( menu ), item );
-	gtk_widget_show( item );
-
-	g_signal_connect( G_OBJECT( item ), "activate",
-	                  G_CALLBACK( icq_set_status_occ ), NULL );
-
-	item = gtk_menu_item_new_with_label ( _("Do Not Disturb") );
-
-	gtk_menu_shell_append( GTK_MENU_SHELL( menu ), item );
-	gtk_widget_show( item );
-
-	g_signal_connect( G_OBJECT( item ), "activate",
-	                  G_CALLBACK( icq_set_status_dnd ), NULL );
-
-	item = gtk_menu_item_new_with_label ( _("Invisible") );
-
-	gtk_menu_shell_append( GTK_MENU_SHELL( menu ), item );
-	gtk_widget_show( item );
-
-	g_signal_connect( G_OBJECT( item ), "activate",
-	                  G_CALLBACK( icq_set_status_invisible ), NULL );
-
-	return menu;
-}
-
-gboolean send_file_request( GtkWidget *widget, int response, gpointer data )
-{
-	GSList *filenames = 0;
-	gchar *filename = 0;
-	gchar *msg;
-	GtkWidget *text, *entry;
-	GtkTextBuffer* text_buffer;
-	GtkTextIter start_iter;
-	GtkTextIter end_iter;
-	UIN_T uin;
-	gint currow;
-
-#ifdef TRACE_FUNCTION
-	g_print( "send_file_request\n" );
-#endif
-
-	if (response != 1)
-	  return FALSE;
-
-	uin = g_object_get_data( G_OBJECT( widget ), "uin" );
-	text = g_object_get_data( G_OBJECT( widget ), "reason" );
-	entry = g_object_get_data( G_OBJECT( widget ), "filelist" );
-
-	for (currow = 0;gtk_clist_get_text( GTK_CLIST(entry), currow, 0, &filename);currow++)
-		filenames = g_slist_append(filenames, filename);
-
-	text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(text));
-	gtk_text_buffer_get_start_iter(text_buffer, &start_iter);
-	gtk_text_buffer_get_end_iter(text_buffer, &end_iter);
-	msg = gtk_text_buffer_get_text(text_buffer, &start_iter, &end_iter, 
-				       FALSE);
-
-	v7_sendfile(mainconnection, uin, msg, filenames);
-
-	/*	TCPSendFileRequest( uin, msg, filenames );  */
-
-	g_slist_free(filenames);
-
-	g_free( msg );
-
-	return FALSE;
-}
-
 void send_url_window( GtkWidget *widget, char *defaulturl )
 {
 	GtkWidget *window;
@@ -712,9 +683,12 @@ void remove_contact(GSList *contact, gboolean rem_history)
 
 	gnomeicu_tree_user_remove (kontakt);
 
-	Contacts = g_slist_remove (Contacts, contact->data);
-
         g_free (contact->data);
+
+	Contacts = g_slist_remove (Contacts, contact->data);	
+
+	contact->data = NULL;
+
 }
 
 void icq_set_status( GtkWidget *widget, gpointer data )
@@ -1122,7 +1096,7 @@ void icq_auth_request_response (GtkDialog *dialog, int response, gpointer data)
 	g_print( "icq_auth_request_response\n" );
 #endif
 
-	if (!is_connected(GTK_WINDOW(dialog), _("You can not answer a authorization request while being disconnected.")))
+	if (!is_connected(GTK_WINDOW(dialog), _("You can not answer a authorization request while disconnected.")))
 		return;
 	if (response == GTK_RESPONSE_YES)
 		v7_grant_auth(mainconnection, data);
@@ -1146,7 +1120,7 @@ void icq_send_url_response (GtkDialog *dialog, int response, struct URLInfo *url
 		char *text;
 
 		g_assert(urlinfo != NULL);
-		if (!is_connected(GTK_WINDOW(dialog), _("You can not send an URL while being disconnected.")))
+		if (!is_connected(GTK_WINDOW(dialog), _("You can not send an URL while disconnected.")))
 			return;
 
 		url = gtk_editable_get_chars (GTK_EDITABLE (urlinfo->url), 0, -1);
@@ -1262,7 +1236,7 @@ static void open_file( GtkWidget *widget, gpointer data )
 
     if (prgm)
     {
-        loc = (int)strstr(prgm, "%f") - (int)prgm;
+        loc = (long int)strstr(prgm, "%f") - (long int)prgm;
         cmd = g_strdup_printf("%s\"%s\"", g_strndup(prgm, loc), filename);
         prgm += loc + 2;
         cmd = g_strdup_printf("%s%s", cmd, prgm);
