@@ -245,7 +245,7 @@ add_message_to_conversation( GtkTextView* conversation,
 
     struct tm *my_tm;
     gchar short_msgtime[40];
-    gchar* short_msgtime_utf8;
+    gchar* short_msgtime_utf8 = NULL;
     gchar* new_str, *stripped_str;
     GtkTextBuffer* text_buffer;
     GtkTextIter end_iter;
@@ -269,8 +269,13 @@ add_message_to_conversation( GtkTextView* conversation,
     
     /* Show the time of this message in the time widget */
     my_tm = localtime (time);
-    strftime (short_msgtime, sizeof (short_msgtime), _("%X"), my_tm);
-    short_msgtime_utf8 = g_locale_to_utf8(short_msgtime, -1, NULL, NULL, NULL);
+    if (my_tm) {
+      strftime (short_msgtime, sizeof (short_msgtime), _("%X"), my_tm);
+      short_msgtime_utf8 = g_locale_to_utf8(short_msgtime, -1, NULL, NULL, NULL);
+    } else {
+      short_msgtime_utf8 = NULL;
+    }
+
 
     /* Strip the \r's out of the message... */
     stripped_str = strip_cr (text);
@@ -279,7 +284,7 @@ add_message_to_conversation( GtkTextView* conversation,
     
     text_buffer = gtk_text_view_get_buffer(conversation);
     
-    header = g_strdup_printf ("%s (%s): ", nick, short_msgtime_utf8);
+    header = g_strdup_printf ("%s (%s): ", nick, short_msgtime_utf8 ? short_msgtime_utf8 :  _("Unknown") );
     
     tag = gtk_text_tag_table_lookup(message_tags, tag_name);
 
@@ -337,14 +342,15 @@ void open_message_dlg_with_message (Contact_Member *contact,
 	  msg_dlg = glade_xml_get_widget (xml, "message_dialog");
 	  
 	  if (message_text && contact->newmsg_blink_timeout == 0 &&
-	      gtk_window_get_focus(GTK_WINDOW(msg_dlg)) &&
-	      !GTK_WIDGET_HAS_FOCUS(gtk_window_get_focus(GTK_WINDOW(msg_dlg)))){
-	    XWMHints *hints;
+	      !gtk_window_is_active(GTK_WINDOW(msg_dlg)) ) {
 	    contact->newmsg_blink_timeout = gtk_timeout_add(500,
 							    (GtkFunction) msg_blink_timeout, 
 							    contact);
-	    
+#if GTK_CHECK_VERSION(2,8,0)
+	    gtk_window_set_urgency_hint(GTK_WINDOW(msg_dlg), TRUE);
+#else
 	    if (GTK_WIDGET_REALIZED(msg_dlg)) {
+	      XWMHints *hints;
 	      hints = XGetWMHints(GDK_WINDOW_XDISPLAY(msg_dlg->window), 
 				  GDK_WINDOW_XWINDOW(msg_dlg->window));
 	      hints->flags |= XUrgencyHint;
@@ -352,6 +358,7 @@ void open_message_dlg_with_message (Contact_Member *contact,
 			  GDK_WINDOW_XWINDOW(msg_dlg->window), hints);
 	      XFree(hints);
 	    }
+#endif
 	  }
 	} else {
           xml = gicu_util_open_glade_xml ("message.glade", "message_dialog");
@@ -463,7 +470,6 @@ void open_message_dlg_with_message (Contact_Member *contact,
 	  if ( !contact->stored_messages) 
 	    gnomeicu_tree_set_contact_icon (contact, get_pixbuf_for_status (contact->status));
 	  
-	  Shortcut_Update (contact);
 	}
 
 	
@@ -483,12 +489,15 @@ gboolean msg_blink_timeout(Contact_Member *contact)
 {
   GtkWidget *msg_dlg = glade_xml_get_widget (contact->msg_dlg_xml, 
 					     "message_dialog");
-  XWMHints *hints;
 
   if (!contact->newmsg_blink_timeout) {
     contact->newmsg_blink = 0;
     set_window_icon( msg_dlg, "gnomeicu-message.png");
+#if GTK_CHECK_VERSION(2,8,0)
+	    gtk_window_set_urgency_hint(GTK_WINDOW(msg_dlg), FALSE);
+#else
     if (GTK_WIDGET_REALIZED(msg_dlg)) {
+      XWMHints *hints;
       hints = XGetWMHints(GDK_WINDOW_XDISPLAY(msg_dlg->window), 
 			  GDK_WINDOW_XWINDOW(msg_dlg->window));
       hints->flags &= ~XUrgencyHint;
@@ -496,6 +505,7 @@ gboolean msg_blink_timeout(Contact_Member *contact)
 		  GDK_WINDOW_XWINDOW(msg_dlg->window), hints);
       XFree(hints);
     }
+#endif
     return FALSE;
   }
   
@@ -639,8 +649,6 @@ show_contact_message (Contact_Member *contact )
   if (!contact->stored_messages) 
     gnomeicu_tree_set_contact_icon (contact,
                                     get_pixbuf_for_status (contact->status));
-
-  Shortcut_Update (contact);
 }
 
 gint
@@ -778,10 +786,10 @@ gboolean msg_url_text_button_pressed (GtkWidget *w, GdkEventButton *event,
 
       if (!g_strrstr (url, "http://") && !g_strrstr (url, "https://") && !g_strrstr (url, "ftp://"))
       {
-        char tmpstr[128] = "http://";
-        strcat(tmpstr, url);
+	char *tmpurl = NULL;
+	tmpurl = g_strdup_printf("http://%s", url);
         g_free (url);
-        url = tmpstr;
+        url = tmpurl;
       }
       
       gnome_url_show(url, NULL);
@@ -884,13 +892,16 @@ void message_dialog_focus_callback(GtkWidget *widget, gpointer data)
     contact->newmsg_blink = TRUE;
 
     set_window_icon( msg_dlg, "gnomeicu-message.png");
-
+#if GTK_CHECK_VERSION(2,8,0)
+    gtk_window_set_urgency_hint(GTK_WINDOW(msg_dlg), FALSE);
+#else
     hints = XGetWMHints(GDK_WINDOW_XDISPLAY(msg_dlg->window), 
 			GDK_WINDOW_XWINDOW(msg_dlg->window));
     hints->flags &= ~XUrgencyHint;
     XSetWMHints(GDK_WINDOW_XDISPLAY(msg_dlg->window), 
 		GDK_WINDOW_XWINDOW(msg_dlg->window), hints);
     XFree(hints);
+#endif
 
     msg_blink_timeout(contact);
   }
