@@ -221,19 +221,30 @@ void update_personal_info ( UIN_T uin )
 	  gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (kontakt->info_dlg_xml, "onlinesince_entry")), _("Offline"));
 	else {
 	  char timebuf[100];
-	  strftime(timebuf,100,"%c",localtime((time_t*)&kontakt->online_since));
-	  gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (kontakt->info_dlg_xml, "onlinesince_entry")), timebuf);
+	  struct tm *mytm = localtime((time_t*)&kontakt->online_since);
+	  if (mytm) {
+	    strftime(timebuf,100,"%c",mytm);
+	    gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (kontakt->info_dlg_xml, "onlinesince_entry")), timebuf);
+	  }
 	}
-	  
-	if( kontakt->member_since) {
+
+	{
+	  struct tm *mytm = NULL;
 	  char timebuf[100];
-	  strftime(timebuf,100,"%c",localtime((time_t*)&kontakt->member_since));
-	  gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_entry")), timebuf);
-	  gtk_widget_show(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_label"));
-	  gtk_widget_show(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_entry"));
-	} else if (GTK_WIDGET_VISIBLE(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_label"))) {
-	  gtk_widget_hide(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_label"));
-	  gtk_widget_hide(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_entry"));
+
+	  if( kontakt->member_since) {
+	    time_t tmp = kontakt->member_since;
+	    mytm = localtime(&tmp);
+	  }
+	  if (mytm) {
+	    strftime(timebuf,100,"%c",mytm);
+	    gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_entry")), timebuf);
+	    gtk_widget_show(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_label"));
+	    gtk_widget_show(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_entry"));
+	  } else if (GTK_WIDGET_VISIBLE(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_label"))) {
+	    gtk_widget_hide(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_label"));
+	    gtk_widget_hide(glade_xml_get_widget (kontakt->info_dlg_xml, "membersince_entry"));
+	  }
 	}
 
 	if ( kontakt->idle_since) {
@@ -261,8 +272,11 @@ void update_personal_info ( UIN_T uin )
 	if (kontakt->status == STATUS_OFFLINE)
 	  if( kontakt->last_seen) {
 	    char timebuf[100];
-	    strftime(timebuf, 100, "%c", localtime(&kontakt->last_seen));
-	    gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (kontakt->info_dlg_xml, "lastseen_entry")), timebuf);
+	    struct tm *mytm = localtime(&kontakt->last_seen);
+	    if (mytm) {
+	      strftime(timebuf, 100, "%c", mytm);
+	      gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (kontakt->info_dlg_xml, "lastseen_entry")), timebuf);
+	    }
 	  } else
 	    gtk_label_set_text (GTK_LABEL (glade_xml_get_widget (kontakt->info_dlg_xml, "lastseen_entry")), _("Never"));
 	else
