@@ -1097,6 +1097,9 @@ rtf_parse_control_word(RTFParserContext* parser_context)
     } else if (! strncmp("\\", word, 1) ) {
 	parser_context->current_pos += 1;
 	g_string_append_c(attributes->text, '\\');
+    } else if (! strncmp("tab", word, 3) ) {
+      parser_context->current_pos += 3;
+      g_string_append_c(attributes->text, '\t');
     } else if (! strncmp("nowidctlpar", word, 11)) {
         /* ignore widow/orphan control */
         parser_context->current_pos += 11;
