@@ -35,7 +35,7 @@ typedef enum {
   NO_RESULTS
 } SearchEnd;
 
-void  search_finished (WORD reqid, SearchEnd end);
+void  search_finished (WORD reqid, gint16 more_results);
 
 
 #endif /* __SEARCH_H__ */
