@@ -11,6 +11,6 @@ struct _ContactPair {
 };
 
 void contact_list_window( CONTACT_PTR contact );
-void received_contact_list_window( CONTACT_PTR contact, GSList *contacts );
+void received_contact_list_window( CONTACT_PTR contact, GList *contacts );
 
 #endif /* __SENDCONTACT__ */
