@@ -503,28 +503,6 @@ int TCPClearQueue( GSList *contact )
   return FALSE;
 }
 
-int TCPSendMessage( UIN_T uin, gchar *msg )
-{
-  
-#ifdef TRACE_FUNCTION
-  g_print( "TCPSendMessage\n" );
-#endif 
-  
-  return TCPSendPacket(uin, ICQ_CMDxTCP_START, ICQ_CMDxTCP_MSG, 0,
-                       0, NULL, 0, msg, 0, 0, TRUE);
-}
-
-int TCPSendURL( UIN_T uin, gchar *msg )
-{
-
-#ifdef TRACE_FUNCTION
-  g_print( "TCPSendURL\n" );
-#endif
-  
-  return TCPSendPacket(uin, ICQ_CMDxTCP_START, ICQ_CMDxTCP_URL, 0,
-                       0, NULL, 0, msg, 0 ,0, TRUE);
-}
-
 int TCPAcceptIncoming( GIOChannel *iochan, GIOCondition cond, gpointer data )
 {
   int sock = g_io_channel_unix_get_fd(iochan);
@@ -714,136 +692,6 @@ int TCPSendFileRequest( UIN_T uin, const gchar *msg, GSList *files )
   return returncode;
 }
 
-/*
-  Should be rebuilt with new contact list sending if we want to keep it
-*/
-
-void TCPSendContactList( GtkWidget *widget, gpointer data )
-{
-  /* We're just blocking thos one for now.. has to be redone */
-  
-  
-  GtkCList *clist = GTK_CLIST( data );
-  gchar *nick;
-  int cx;
-  tcp_message *m;
-
-  GSList *contact;
-
-  int sock;
-  unsigned short intsize;
-  guchar *msg;
-  BYTE *buffer;
-  UIN_T uin = g_object_get_data (G_OBJECT (widget ), "uin" );
-
-  typedef struct
-  {
-    BYTE uin_a[4];
-    BYTE version[2];
-    BYTE cmd[2];
-    BYTE zero[2];
-    BYTE uin_b[4];
-    BYTE command[2];
-    BYTE msg_length[2];
-  } tcp_head;
-
-  typedef struct
-  {
-    BYTE ip[4];
-    BYTE real_ip[4];
-    BYTE port[4];
-    BYTE four;
-    BYTE zero[4];
-    BYTE seq[4];
-  } tcp_tail;
-
-  struct
-  {
-    tcp_head head;
-    const gchar *body;
-    tcp_tail tail;
-  } packet;
-
-  return;
-
-#ifdef TRACE_FUNCTION
-  g_print( "TCPSendContactList\n" );
-#endif
-
-  msg = g_strdup_printf( "%d\xFE", clist->rows );
-
-  for( cx = 0; cx < clist->rows; cx ++ )
-    {
-      gtk_clist_get_text( clist, cx, 0, &nick );
-      msg = g_strconcat( msg, nick, "\xFE", NULL );
-      gtk_clist_get_text( clist, cx, 1, &nick );
-      msg = g_strconcat( msg, nick, "\xFE", NULL );
-    }
-
-  DW_2_Chars( packet.head.uin_a, atoi (our_info->uin) );
-  Word_2_Chars( packet.head.version, 0x0003 );
-  Word_2_Chars( packet.head.cmd, ICQ_CMDxTCP_START );
-  Word_2_Chars( packet.head.zero, 0x0000 );
-  DW_2_Chars( packet.head.uin_b, atoi (our_info->uin) );
-  Word_2_Chars( packet.head.command, ICQ_CMDxTCP_CONT_LIST );
-  Word_2_Chars( packet.head.msg_length, ( strlen( msg ) + 1 ) );
-
-  packet.body = msg;
-
-  contact = Find_User( uin );
-  if( contact == NULL  || kontakt->has_direct_connect != YES)
-    return;
-
-  DW_2_IP( packet.tail.ip, our_ip );
-  DW_2_IP( packet.tail.real_ip, our_ip );
-  DW_2_Chars( packet.tail.port, our_port );
-  packet.tail.four = 0x04;
-  if( kontakt->status == STATUS_DND || kontakt->status == STATUS_OCCUPIED )
-    DW_2_Chars( packet.tail.zero, 0x00200000 );
-  else
-    DW_2_Chars( packet.tail.zero, 0x00100000 );
-  DW_2_Chars( packet.tail.seq, kontakt->tcp_seq );
-
-  /* If the user is offline, we use UDP to avoid hanging */
-  if( kontakt->status == STATUS_OFFLINE )
-    return;
-
-  /*** Construct packet ***/
-  intsize = sizeof( tcp_head ) + sizeof( tcp_tail ) + strlen( msg ) + 1;
-  buffer = (BYTE*)g_malloc0( strlen( "SEND CONTACT LIST" ) + 1 + intsize + 2 );
-
-  Word_2_Chars (buffer, intsize);
-  memcpy( buffer+2, &packet.head, sizeof( packet.head ) );
-  memcpy( buffer+2 + sizeof( packet.head ), packet.body,
-          strlen( packet.body ) + 1 );
-  memcpy( buffer+2 + sizeof( packet.head ) +
-          strlen( packet.body ) + 1,
-          &packet.tail, sizeof( packet.tail ) );
-  strcpy( buffer + 2 + intsize, "SEND CONTACT LIST" );
-  /************************/
-
-  m = tcp_prepare_message( kontakt, buffer, g_strdup( msg ),
-                           kontakt->tcp_seq--);
-
-  sock = TCPGainConnection( kontakt->current_ip, kontakt->port, contact );
-  if( sock != -1 )
-    m->timeout = gtk_timeout_add( 30000, (GtkFunction)TCPTimeout, m );
-
-  if( sock == -2 ) /* We're waiting for a connection */
-    {
-      gnomeicu_spinner_start();
-      return;
-    }
-
-  if( sock != -1 )
-    TCPClearQueue( contact );
-  else
-    return;
-
-  gnomeicu_spinner_start();
-  return;
-}
-
 /*** Local functions ***/
 int TCPInitChannel( GIOChannel *source, GIOCondition cond, gpointer data )
 {
@@ -1034,7 +882,7 @@ struct {
 
   gchar *countstr, *tmp = NULL;
   ContactPair *cpair;
-  GSList *contacts = NULL;
+  GList *contacts = NULL;
   int i, count;
 
 #ifdef TRACE_FUNCTION
@@ -1284,7 +1132,7 @@ struct {
         cpair->nick = g_strdup(cpair->nick);
         tmp++;
 
-        contacts = g_slist_append(contacts, cpair);
+        contacts = g_list_append(contacts, cpair);
       }
 
       contact_list_received (uin, contacts, time(NULL));
