@@ -53,8 +53,6 @@ typedef struct
 	GtkWidget *dialog;
 } tcp_message;
 
-int TCPSendMessage( UIN_T uin, gchar *msg );
-int TCPSendURL( UIN_T uin, gchar *msg );
 int TCPAcceptIncoming( GIOChannel *iochan, GIOCondition cond, gpointer data);
 int TCPRetrieveAwayMessage( GSList *contact, gpointer data );
 
@@ -62,8 +60,6 @@ int TCPAcceptFile( XferInfo *xfer );
 int TCPRefuseFile( XferInfo *xfer );
 int TCPSendFileRequest( UIN_T uin, const gchar *msg, GSList *files );
 
-void TCPSendContactList( GtkWidget *widget, gpointer data );
-
 void TCPSendHandShake(Contact_Member *contact, DWORD sessionid, int socket);
 void TCPSendHandShakeAck(int socket);
 
