@@ -17,6 +17,8 @@
 #include "v7snac13.h"
 #include "groups.h"
 #include "grpmgr.h"
+#include "auth.h"
+#include "util.h"
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
@@ -37,13 +39,9 @@ static void lists_change_list_notify (GtkWidget *widget, gpointer data);
 static void lists_change_list( GtkWidget *widget, gpointer data, gint type );
 static void add_files( GtkWidget *widget, gpointer data);
 static void remove_files( GtkWidget *widget, gpointer data);
-static void add_files_final( GtkWidget *button, gpointer data );
 static void remove_user (GtkDialog *dialog, int response, gpointer data);
 static void user_change_group (GtkWidget *widget, GroupInfo *data);
 
-enum {
-        ICQ_RESPONSE_SEND = 1
-};
 
 GtkWidget *user_popup (Contact_Member *contact)
 {
@@ -377,24 +375,30 @@ void request_file( GtkWidget *widget, GList *files, gpointer data )
 {
 	GSList *contact;
 
-        GList *file;
-
-	GtkWidget *window;
-	GtkWidget *dialog_vbox1;
-	GtkWidget *vbox1;
-	GtkWidget *label3;
-	GtkWidget *hbox1;
-	GtkWidget *label1;
-	GtkWidget *filelist;
-	GtkWidget *label2;
-	GtkWidget *scrolledwindow2;
-	GtkWidget *scrolledwindow1;
-	GtkWidget *text1;
-	GtkWidget *button1;
+	GladeXML *dialogxml;
+	GtkWidget *dialog;
+	GtkWidget *treeview;
+	GtkWidget *textview;
 	GtkWidget *addbutton;
 	GtkWidget *removebutton;
 
-	gchar *str, *filenames[1];
+	GtkTextBuffer* text_buffer;
+	GtkTextIter start_iter;
+	GtkTextIter end_iter;
+	gchar *msg;
+
+	GtkListStore *filelist;
+	GtkTreeViewColumn *column;
+	GtkCellRenderer   *renderer;
+	GtkTreeIter iter;
+	GtkTreeSelection *selection;
+
+	GSList *filenames = NULL;
+
+	int response;
+
+	gchar *str;
+
 
 #ifdef TRACE_FUNCTION
 	g_print( "request_file\n" );
@@ -407,114 +411,127 @@ void request_file( GtkWidget *widget, GList *files, gpointer data )
 	if( contact == NULL )
 		return;
 
-	window = gtk_dialog_new_with_buttons (_("Send File"),
-                                              GTK_WINDOW (MainData->window),
-                                              GTK_DIALOG_DESTROY_WITH_PARENT,
-                                              NULL);
+	dialogxml = gicu_util_open_glade_xml("filexfer.glade",
+					     "file_send_dialog");
+	if (dialogxml == NULL) {
+	  return;
+	}
 
-	gtk_window_set_role (GTK_WINDOW (window), "GnomeICU_SendFile");
-	gtk_window_set_default_size( GTK_WINDOW( window ), 350, 250 );
-	gtk_window_set_policy (GTK_WINDOW (window), FALSE, TRUE, FALSE);
+	
+	dialog = glade_xml_get_widget(dialogxml, "file_send_dialog");
+	treeview = glade_xml_get_widget(dialogxml, "files_treeview");
+	addbutton = glade_xml_get_widget(dialogxml, "add_button");
+	removebutton = glade_xml_get_widget(dialogxml, "remove_button");
+	textview = glade_xml_get_widget(dialogxml, "reason_textview");
 
-        set_window_icon( window, "gnomeicu-file.png" );
-
-	dialog_vbox1 = GTK_DIALOG (window)->vbox;
-
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_widget_show (vbox1);
-	gtk_box_pack_start (GTK_BOX (dialog_vbox1), vbox1, TRUE, TRUE, 0);
+	set_window_icon( dialog, "gnomeicu-file.png" );
 
 	str = g_strdup_printf( _("Send File to %s:"), kontakt->nick );
+	gtk_window_set_title(GTK_WINDOW(dialog), str);
+	g_free(str);
 
-	label3 = gtk_label_new ( str );
-	g_free( str );
-	gtk_widget_show (label3);
-	gtk_box_pack_start (GTK_BOX (vbox1), label3, FALSE, FALSE, 0);
 
-	hbox1 = gtk_hbox_new (FALSE, 0);
-	gtk_widget_show (hbox1);
+	filelist = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_POINTER);
 
-	label1 = gtk_label_new (_("Files:"));
-	gtk_widget_show (label1);
-	gtk_box_pack_start (GTK_BOX (vbox1), label1, FALSE, FALSE, 0);
-	gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);
+	gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), GTK_TREE_MODEL(filelist));
 
-	scrolledwindow2 = gtk_scrolled_window_new (NULL, NULL);
-	gtk_widget_show (scrolledwindow2);
-	gtk_box_pack_start (GTK_BOX (vbox1), scrolledwindow2, TRUE, TRUE, 0);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow2), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+	renderer = gtk_cell_renderer_text_new ();
 
-	filelist = gtk_clist_new(1);
+	column = gtk_tree_view_column_new_with_attributes("Filenames",
+							  renderer,
+							  "text", 0,
+							  NULL);
 
-	gtk_clist_set_selection_mode(GTK_CLIST(filelist), GTK_SELECTION_EXTENDED);
-        for ( file = files; file; file = file->next )
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+	
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
+
+	gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
+
+
+	/* for data passed from DnD */
+
+	for (; files; files = files->next )
         {
-            char *data = file->data;
+            char *rawdata = files->data;
+	    char *filename = NULL;
+	    char *utf8filename = NULL;
 
             /* Since its a file, we can strip the protocol type */
-            if (strncmp (data, "file:", 5) == 0)
-                data += 5;
+            if (strncmp (data, "file:", 5) == 0) {
+	      filename = g_filename_from_uri(rawdata, NULL,NULL);
+	      if (filename == NULL)
+		continue;
+	    } else {
+	      filename = g_strdup(rawdata);
+	    }
+	    
+	    utf8filename = g_filename_to_utf8(filename, -1,
+					      NULL, NULL, NULL);
+					      
+	    
 
-            filenames[0] = data;
-            gtk_clist_append(GTK_CLIST(filelist), filenames);
-        }
-	gtk_widget_show (filelist);
+	    
 
-	gtk_container_add (GTK_CONTAINER (scrolledwindow2), filelist);
+	    gtk_list_store_append(filelist, &iter);
+	    gtk_list_store_set(filelist,
+			       0, utf8filename,	
+			       1, filename,
+			       -1);
 
-	gtk_box_pack_start (GTK_BOX (vbox1), hbox1, FALSE, TRUE, 0);
+	    g_free(utf8filename);
+	}
+
+	g_object_set_data (G_OBJECT (dialog), "filelist", filelist);
 
-	addbutton = gtk_button_new_with_label(_("Add files..."));
-	gtk_widget_show (addbutton);
-	gtk_box_pack_end (GTK_BOX (hbox1), addbutton, FALSE, FALSE, 3);
 	g_signal_connect (G_OBJECT (addbutton), "clicked",
-			  G_CALLBACK (add_files), filelist);
-
-	removebutton = gtk_button_new_with_label(_("Remove files"));
-	gtk_widget_show (removebutton);
-	gtk_box_pack_end (GTK_BOX (hbox1), removebutton, FALSE, FALSE, 3);
+			  G_CALLBACK (add_files), dialog);
 	g_signal_connect (G_OBJECT (removebutton), "clicked",
-			  G_CALLBACK (remove_files), filelist);
-
-	label2 = gtk_label_new (_("Reason:"));
-	gtk_widget_show (label2);
-	gtk_box_pack_start (GTK_BOX (vbox1), label2, FALSE, FALSE, 0);
-	gtk_label_set_justify (GTK_LABEL (label2), GTK_JUSTIFY_LEFT);
-	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
-
-	scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
-	gtk_widget_show (scrolledwindow1);
-	gtk_box_pack_start (GTK_BOX (vbox1), scrolledwindow1, TRUE, TRUE, 0);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-
-	text1 = gtk_text_view_new ();
-	gtk_widget_show (text1);
-	gtk_text_view_set_wrap_mode( GTK_TEXT_VIEW( text1 ), GTK_WRAP_WORD);
-	gtk_text_view_set_editable( GTK_TEXT_VIEW( text1 ), TRUE );
-	gtk_container_add (GTK_CONTAINER (scrolledwindow1), text1);
-
-	gtk_dialog_add_button (GTK_DIALOG (window),
-					 GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
-	button1 = make_button_with_pixmap (_("Send"), GTK_STOCK_JUMP_TO);
-	gtk_dialog_add_action_widget (GTK_DIALOG (window), button1, ICQ_RESPONSE_SEND);
-
-	g_object_set_data (G_OBJECT (window), "reason", text1);
-	g_object_set_data (G_OBJECT (window), "uin",
-			     kontakt->uin);
-	g_object_set_data (G_OBJECT (window), "filelist", filelist);
+			  G_CALLBACK (remove_files), treeview);
 
 
-	gtk_dialog_set_default_response (GTK_DIALOG (window), ICQ_RESPONSE_SEND);
 
-	g_signal_connect (G_OBJECT (window), "response", 
-	                  G_CALLBACK (send_file_request), NULL);
-
-	g_signal_connect_swapped (G_OBJECT (window), "response", 
-	                          G_CALLBACK (gtk_widget_destroy), window);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 
-	gtk_widget_show (window);
+	response = gtk_dialog_run(GTK_DIALOG(dialog));
+
+	if (response = GTK_RESPONSE_OK) {
+	  if (contact->data) {
+	  
+	    text_buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(textview));
+	    gtk_text_buffer_get_start_iter(text_buffer, &start_iter);
+	    gtk_text_buffer_get_end_iter(text_buffer, &end_iter);
+	    msg = gtk_text_buffer_get_text(text_buffer, &start_iter, &end_iter, 
+					   FALSE);
+
+	    /*
+	     * get filenames
+	     */
+	    if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(filelist), &iter)) {
+
+	      do {
+		gchar *filename;
+
+		gtk_tree_model_get(GTK_TREE_MODEL(filelist), &iter, 
+				   1, &filename,
+				   -1);
+
+		filenames = g_slist_prepend(filenames, filename);
+
+	      } while (gtk_tree_model_iter_next(GTK_TREE_MODEL(filelist), &iter));
+
+
+	      v7_sendfile(mainconnection, kontakt->uin, msg, filenames);
+	    }
+	  }
+	}
+	
+	g_slist_foreach(filenames, (GFunc)g_free, NULL);
+	g_slist_free(filenames);
+
+	gtk_widget_destroy(dialog);
+
 }
 
 static void retrieve_away_message( GtkWidget *widget, gpointer data )
@@ -525,7 +542,7 @@ static void retrieve_away_message( GtkWidget *widget, gpointer data )
 	g_print( "retrieve_away_message\n" );
 #endif
 
-	if (!is_connected(GTK_WINDOW(MainData->window), _("You can not retrieve away messages while being disconnected.")))
+	if (!is_connected(GTK_WINDOW(MainData->window), _("You can not retrieve away messages while disconnected.")))
 		return;
 
 	contact = Contacts;
@@ -551,7 +568,7 @@ static void add_user_to_list( GtkWidget *widget, gpointer data )
 	g_print( "add_user_to_list\n" );
 #endif
 
-	if (!is_connected(GTK_WINDOW(MainData->window), _("You can not add a user to a list while being disconnected.")))
+	if (!is_connected(GTK_WINDOW(MainData->window), _("You can not add a user to a list while disconnected.")))
 		return;
 
 	contact = g_object_get_data(G_OBJECT(widget), "contact");
@@ -569,7 +586,7 @@ request_auth (GtkWidget *widget, Contact_Member *contact)
   g_assert (contact != NULL);
 
   if (!is_connected(GTK_WINDOW(MainData->window),
-                    _("You can not authorize a contact while being disconnected.")))
+                    _("You can not authorize a contact while disconnected.")))
     return;
 
   auth_request_msg_box (contact->nick, contact->uin);
@@ -622,9 +639,7 @@ static void remove_user_question( GtkWidget *widget, gpointer data )
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 0);
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
 
-	string = g_markup_escape_text(kontakt->nick, strlen(kontakt->nick));
-	message = g_strdup_printf (_("Are you sure you wish to remove %s from your contact list?"),string);
-	g_free(string);
+	message = g_strdup_printf (_("Are you sure you wish to remove %s from your contact list?"),kontakt->nick);
 	string = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%s",
 	                          _("Remove User?"), message);
 
@@ -682,7 +697,7 @@ static void lists_change_list( GtkWidget *widget, gpointer data, gint type )
     g_print( "lists_change_lists" );
 #endif
 
-    if (!is_connected(GTK_WINDOW(MainData->window), _("You can not change a list while being disconnected.")))
+    if (!is_connected(GTK_WINDOW(MainData->window), _("You can not change a list while disconnected.")))
         return;
     contact = data;
 
@@ -737,53 +752,98 @@ static void lists_change_list( GtkWidget *widget, gpointer data, gint type )
 
 static void add_files( GtkWidget *widget, gpointer data)
 {
-  GtkWidget *filebrowser;
+  GtkWidget *filechooser;
+  GtkWidget *parent = data;
+  GtkListStore *filelist;
+  GSList *files, *file;
+  gchar *utf8filename;
+  GtkTreeIter iter;
 
-  filebrowser = gtk_file_selection_new("Send Files...");
-  gtk_file_selection_set_select_multiple(GTK_FILE_SELECTION(filebrowser),
-				 TRUE);
-  g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (filebrowser)->ok_button),
-		    "clicked",
-		    G_CALLBACK (add_files_final),
-		    filebrowser);
+  filelist = g_object_get_data(G_OBJECT(parent), "filelist");
 
-  g_object_set_data(G_OBJECT(filebrowser), "gtkclist", data);
+  filechooser = gtk_file_chooser_dialog_new (_("Send Files..."),
+					     GTK_WINDOW(parent),
+					     GTK_FILE_CHOOSER_ACTION_OPEN,
+					     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					     GTK_STOCK_ADD, GTK_RESPONSE_ACCEPT,
+					     NULL);
 
-  g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (filebrowser)->ok_button),
-			    "clicked",
-			    G_CALLBACK (gtk_widget_destroy), 
-			    filebrowser); 
+  gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(filechooser), TRUE);
+  gtk_file_chooser_set_local_only(GTK_FILE_CHOOSER(filechooser), TRUE);
 
-   g_signal_connect_swapped (G_OBJECT (GTK_FILE_SELECTION (filebrowser)->cancel_button),
-                             "clicked",
-                             G_CALLBACK (gtk_widget_destroy),
-                             filebrowser); 
+    
+  if (gtk_dialog_run (GTK_DIALOG (filechooser)) == GTK_RESPONSE_ACCEPT)
+  {
+    files = gtk_file_chooser_get_filenames (GTK_FILE_CHOOSER (filechooser));
 
+    for (file = files;
+	 file;
+	 file = g_slist_next(file)) {
 
-   gtk_widget_show_all(filebrowser);
+      utf8filename = g_filename_to_utf8(file->data, -1,
+					NULL, NULL, NULL);
+
+      if (!utf8filename)
+	continue;
+	    
+
+      gtk_list_store_append(filelist, &iter);
+      gtk_list_store_set(filelist, &iter,
+			 0, utf8filename,	
+			 1, file->data,
+			 -1);
+
+      g_free(utf8filename);
+    }
+    g_slist_free(files);
+  }
+
+  gtk_widget_destroy(filechooser);
+
+  
   
 }
 
 static void remove_files( GtkWidget *widget, gpointer data)
 {
-	GList *selected;
-
-	while ((selected = GTK_CLIST(data)->selection))
-		gtk_clist_remove(GTK_CLIST(data), GPOINTER_TO_INT(selected->data) );
-}
-
-static void add_files_final( GtkWidget *button, gpointer data )
-{
-  GtkWidget *filesel = data;
-  GtkWidget *clist = g_object_get_data(G_OBJECT(filesel), "gtkclist");
-  gchar **files;
-
-  files = gtk_file_selection_get_selections(GTK_FILE_SELECTION(filesel));
-
-  gtk_clist_append(GTK_CLIST(clist), files);
+  GList *selected, *sel;
+  GtkWidget *treeview = data;
+  GtkTreeModel *model;
+  GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
+  GtkTreeIter *iters;
+  int count, i;
   
+	
+
+  count = gtk_tree_selection_count_selected_rows(selection);
+
+  if (count == 0)
+    return;
+
+  selected = gtk_tree_selection_get_selected_rows(selection, &model);
+
+  iters = g_new0(GtkTreeIter, count);
+
+  for(sel = selected, i=0;
+      sel;
+      sel = g_list_next(sel)) {
+    if (gtk_tree_model_get_iter(model, &iters[i], sel->data))
+      i++;
+    
+  }
+  g_list_foreach (selected, (GFunc)gtk_tree_path_free, NULL);
+  g_list_free (selected);
+  
+  count = i;
+  for(i = 0; i < count; i++) {
+    gtk_list_store_remove(GTK_LIST_STORE(model),
+			  &iters[i]);
+  }
+
+  g_free(iters);
 }
 
+
 void remove_user (GtkDialog *dialog, int response, gpointer data)
 {
 	GSList *contact;
@@ -794,7 +854,7 @@ void remove_user (GtkDialog *dialog, int response, gpointer data)
 
 	if (response == GTK_RESPONSE_YES)
 	{
-		if (!is_connected(GTK_WINDOW(dialog), _("You can not remove a contact while being disconnected.")))
+		if (!is_connected(GTK_WINDOW(dialog), _("You can not remove a contact while disconnected.")))
 			return;
 
 		contact = g_object_get_data (G_OBJECT (dialog), "contact");
@@ -834,16 +894,9 @@ user_change_group (GtkWidget *widget, GroupInfo *d)
 	contact = g_object_get_data (G_OBJECT (widget), "contact");
 
 	if (contact) {
-		if (!is_connected (GTK_WINDOW (MainData->window), _("You can not change the group of a user while being disconnected.")))
+		if (!is_connected (GTK_WINDOW (MainData->window), _("You can not change the group of a user while disconnected.")))
 			return;
 
-		uid = v7_user_change_group (mainconnection, contact, d->gid, d->name);
-
-		gnomeicu_tree_user_remove (contact);
-		contact->gid = d->gid;
-		contact->uid = uid;
-		gnomeicu_tree_user_add (contact);
-                if (contact->status != STATUS_OFFLINE)
-                  gnomeicu_tree_user_online (contact);
+		v7_user_change_group (mainconnection, contact, d->gid, d->name);
 	}
 }
