@@ -6,12 +6,12 @@
 ***************************/
 
 #include <errno.h>
+#include <sys/types.h>
 #include <netinet/in.h>
 #include <pwd.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/stat.h>
 #include <sys/un.h>
@@ -264,31 +264,33 @@ void userserver_handler(gint sock)
       /* COMMAND: HIDE */
       else if (!strcasecmp(cmd,"hide"))
 	{
-	  gtk_window_get_position (GTK_WINDOW (app), &MainData->x, 
-				     &MainData->y);
-	  gtk_widget_hide(app);
+	  gtk_window_get_position (GTK_WINDOW (MainData->window),
+				   &MainData->x, &MainData->y);
+	  gtk_widget_hide(MainData->window);
 	  MainData->hidden = TRUE;
 	}
 			
       /* COMMAND: SHOW */
       else if (!strcasecmp(cmd,"show"))
 	{
-	  gtk_window_move (GTK_WINDOW (app), MainData->x, MainData->y);
-	  gtk_window_present (GTK_WINDOW(app));
+	  gtk_window_move (GTK_WINDOW (MainData->window),
+			   MainData->x, MainData->y);
+	  gtk_window_present (GTK_WINDOW(MainData->window));
 	  MainData->hidden = FALSE;
 	}
       
       /* COMMAND: SHOWHIDE */
       else if (!strcasecmp(cmd,"showhide"))
 	{
-	  if (GTK_WIDGET_VISIBLE (app)) {
-	    gtk_window_get_position (GTK_WINDOW (app), &MainData->x, 
-				     &MainData->y);
-	    gtk_widget_hide (app);
+	  if (GTK_WIDGET_VISIBLE (MainData->window)) {
+	    gtk_window_get_position (GTK_WINDOW (MainData->window),
+				     &MainData->x, &MainData->y);
+	    gtk_widget_hide (MainData->window);
 	    MainData->hidden = TRUE;
 	  } else {
-	    gtk_window_move (GTK_WINDOW (app), MainData->x, MainData->y);
-	    gtk_window_present (GTK_WINDOW(app));
+	    gtk_window_move (GTK_WINDOW (MainData->window),
+			     MainData->x, MainData->y);
+	    gtk_window_present (GTK_WINDOW(MainData->window));
 	    MainData->hidden = FALSE;
 	  }
 	}
@@ -718,7 +720,6 @@ void show_contact_message_client( GSList *contact, gint sock )
 		g_free( kontakt->stored_messages->data );
 		kontakt->stored_messages = g_slist_remove( kontakt->stored_messages, kontakt->stored_messages->data );
 
-		Shortcut_Update( kontakt );
 	}
 }
 
