@@ -755,27 +755,6 @@ get_status_str (DWORD status)
 	}
 }
 
-/********************************************
-Converts an ip number character sequence to
-a DWORD
-The IP number is stored in big endian byte
-order in the icq protocol
-*********************************************/
-DWORD IP_2_DW( const guchar buf[] )
-{
-       DWORD i;
-
-       i= buf[0];
-       i <<= 8;
-       i+= buf[1];
-       i <<= 8;
-       i+= buf[2];
-       i <<= 8;
-       i+= buf[3];
-
-       return i;
-}
-
 
 /********************************************
 Converts an intel endian character sequence to
@@ -811,20 +790,6 @@ WORD Chars_2_Word( const guchar *buf )
 	return i;
 }
 
-/********************************************
-Converts a DWORD to an IP number character 
-sequence
-The IP number is stored in big endian byte order
-for use in the icq protocol
-*********************************************/
-void DW_2_IP( guchar buf[], DWORD num )
-{
-       buf[0] = ( guchar ) ((num)>>24)& 0x000000FF;
-       buf[1] = ( guchar ) ((num)>>16)& 0x000000FF;
-       buf[2] = ( guchar ) ((num)>>8)& 0x000000FF;
-       buf[3] = ( guchar ) (num) & 0x000000FF;
-}
-
 /********************************************
 Converts a DWORD to
 an intel endian character sequence 
@@ -1008,14 +973,11 @@ GSList * Add_User( UIN_T uin, const gchar *name, gboolean inlist )
 	contactdata->confirmed = inlist; /* Needs confirmation if not manually added*/
 
 	if( !strcmp (uin, "10") ) {
-		g_free(contactdata->nick);
 		contactdata->nick = g_strdup(_("Web Message"));
 	} else {
 		if( name == NULL || name[0] == '\0' ) {
-			g_free(contactdata->nick);
 			contactdata->nick = g_strdup(uin);
 		} else {
-			g_free(contactdata->nick);
 			contactdata->nick = g_strdup(name);
 		}
 	}
