@@ -135,31 +135,38 @@ V7Packet *read_flap(V7Connection *conn)
     
     /* If we have the whole header */
     if (conn->bytes_read_in_latest == 6) {
+      if (conn->latest_head[0] != 0x2A) {
+	g_error("Error reading packet, the first byte of a FLAP is 0x%x, "
+		"it should be 0x2A\n", conn->latest_packet[0]);
+      }
       conn->latest_packet = g_new0(V7Packet, 1);
       conn->latest_packet->conn = conn;
       conn->latest_packet->channel = conn->latest_head[1];
       /* sequence number not read */
       conn->latest_packet->len = CharsBE_2_Word (conn->latest_head+4);
       
-      conn->latest_packet->data = g_malloc(conn->latest_packet->len);
+
+      conn->latest_packet->buf = v7_buffer_new(
+          g_malloc(conn->latest_packet->len), 
+          conn->latest_packet->len, 
+          TRUE);
       
-      conn->latest_head[0] = '\0';
+      conn->latest_head[0] = 0;
       conn->bytes_read_in_latest = 0;
     } else
       return NULL;
   }
 
   if ((nr = read(conn->fd, 
-		 conn->latest_packet->data + 
+		 conn->latest_packet->buf->here + 
 		 conn->bytes_read_in_latest,
 		 conn->latest_packet->len - 
 		 conn->bytes_read_in_latest)) < 0) 
     return NULL;
   
-  
   conn->bytes_read_in_latest += nr;
   conn->total_read +=nr;
-  
+
   if (conn->bytes_read_in_latest == conn->latest_packet->len) {
     V7Packet *packet;
     packet = conn->latest_packet;
@@ -174,91 +181,73 @@ V7Packet *read_flap(V7Connection *conn)
   
 }
 
+void free_flap (V7Packet *packet)
+{
+  v7_buffer_free (packet->buf);
+  g_free (packet);
+}
+
 Snac *read_snac(const V7Packet *packet)
 {
-  Snac *snac;
+  Snac *snac = NULL;
 
   g_assert(packet != NULL);
 
   snac = g_new0(Snac, 1);
 
-  snac->family = CharsBE_2_Word(packet->data);
-  snac->type   = CharsBE_2_Word(packet->data+2);
-  snac->flags[0] = packet->data[4];
-  snac->flags[1] = packet->data[5];
-  snac->reqid  = CharsBE_2_DW(packet->data+6);
-  snac->datalen= packet->len - 10;
-  snac->data = g_malloc0 (snac->datalen);
+  snac->family = v7_buffer_get_w_be (packet->buf, error_out);
+  snac->type   = v7_buffer_get_w_be (packet->buf, error_out);
+  snac->flags[0] = v7_buffer_get_c (packet->buf, error_out);
+  snac->flags[1]  = v7_buffer_get_c (packet->buf, error_out);
+  snac->reqid  = v7_buffer_get_dw_be (packet->buf, error_out);
+  snac->datalen = packet->len;
+  snac->buf = packet->buf;
   snac->packet = packet;
-  g_memmove (snac->data, packet->data + 10, snac->datalen);
 
   return snac;
+
+ error_out:
+  g_free (snac);
+  return NULL;
 }
 
-TLV *new_tlv(const BYTE *place)
+void free_snac (Snac *snac)
 {
-  TLV *tlv;
+  g_assert (snac);
+
+  g_free (snac);
+}
+
+TLV *_read_tlv (V7Buffer *buf)
+{
+  TLV *tlv = NULL;
+
+  g_assert (buf);
 
-  g_assert(place != NULL);
-  
   tlv = g_new0(TLV, 1);
-  
-  tlv->type = CharsBE_2_Word(place);
-  tlv->len = CharsBE_2_Word(place+2);
 
-  tlv->value = g_malloc0(tlv->len + 1);
-
-  /* Make sure its null terminated */
-  tlv->value[tlv->len] = '\0';
-
-  g_memmove(tlv->value, place+4, tlv->len);
+  tlv->type = v7_buffer_get_w_be (buf, out_err);
+  tlv->len = v7_buffer_get_w_be (buf, out_err);
+  tlv->buf = v7_buffer_get_v7buf(buf, tlv->len, out_err);
 
   if (preferences_get_bool (PREFS_ICQ_DEBUG_SNAC))
     g_print("newtlv type:0x%x len: %d\n", tlv->type, tlv->len);
 
   return tlv;
+
+ out_err:
+  g_free (tlv);
+  return NULL;
 }
 
 
-TLV *new_tlv_check(const BYTE *place, int len)
+void free_tlv (TLV *tlv) 
 {
-  TLV *tlv;
-
-  g_assert(place != NULL);
+  if (!tlv)
+    return;
   
-  if (len < 4 + CharsBE_2_Word(place+2))
-    return NULL;
-
-  tlv = g_new0(TLV, 1);
-  
-  tlv->type = CharsBE_2_Word(place);
-  tlv->len = CharsBE_2_Word(place+2);
-
-
-  tlv->value = g_malloc0(tlv->len + 1);
-
-  /* Make sure its null terminated */
-  tlv->value[tlv->len] = '\0';
-
-  g_memmove(tlv->value, place+4, tlv->len);
-
-  if (preferences_get_bool (PREFS_ICQ_DEBUG_SNAC))
-    g_print("newtlv type:0x%x len: %d\n", tlv->type, tlv->len);
-
-  return tlv;
-}
-
-
-
-
-
-
-void delete_tlv (TLV *tlv) 
-{
-  if (tlv != NULL) {
-    g_free(tlv->value);
-    g_free(tlv);
-  }
+  v7_buffer_free (tlv->buf);
+  g_free(tlv);
 }
 
 
@@ -494,15 +483,16 @@ void display_tlv(const TLV *tlv)
   g_assert(tlv != NULL);
   g_print ("T: %d L: %d V(w:%d dw:%d): %s\n",
              tlv->type, tlv->len,
-             (tlv->len==2) ? CharsBE_2_Word(tlv->value) : 0,
-             (tlv->len==4) ? CharsBE_2_DW(tlv->value)   : 0,
-             tlv->value);
+             (tlv->len==2) ? CharsBE_2_Word(tlv->buf->here) : 0,
+             (tlv->len==4) ? CharsBE_2_DW(tlv->buf->here)   : 0,
+             tlv->buf->here);
 
 }
 
-void packet_print_v7 (const V7Packet *packet)
+static void packet_print_v7 (const V7Packet *packet)
 {
- 
+  V7Buffer buf;
+
 #ifdef TRACE_FUNCTION
   g_print( "packet_print_v7\n" );
 #endif
@@ -512,13 +502,17 @@ void packet_print_v7 (const V7Packet *packet)
   if (packet->channel == 2) {
     Snac *snac;
 
+    memcpy(&buf, packet->buf, sizeof(V7Buffer));
+
     snac = read_snac(packet);
 
+    memcpy(packet->buf, &buf, sizeof(V7Buffer));
+
     packet_print_v7_snac(snac);
 
     g_free(snac);
   }  else
-    print_data(packet->data, packet->len);
+    print_data(packet->buf->buf, packet->len);
 
 }
 
@@ -533,7 +527,7 @@ void packet_print_v7_snac (const Snac *snac)
   g_print("Fam:0x%x Type:0x%x Flags:0x%x%x ReqID:0x%x\n", snac->family, snac->type,
           snac->flags[0], snac->flags[1], snac->reqid);
   
-  print_data(snac->data, snac->datalen);
+  print_data(snac->buf->here, snac->datalen);
 
 }
 
