@@ -1,12 +1,14 @@
 /*******************************************
   Basic code for ICQ v7-8 protocol (Oscar)
-  Olivier Crete (c) 2001
+  Olivier Crete (c) 2001-2007
   GnomeICU
  *******************************************/
 
 #ifndef __V7BASE_H__
 #define __V7BASE_H__
 
+#include "v7buffer.h"
+
 typedef struct _V7Connection V7Connection;
 typedef struct _V7Packet     V7Packet;
 typedef enum   _ConnStatus   ConnStatus;
@@ -32,8 +34,6 @@ enum _ReqType {
   NEW_USER_VERIFICATION
 };
 
-#define TLV_HEADER 4   /* TLV header size in bytes */
-
 #define CHANNEL_NEWCONN      1
 #define CHANNEL_SNAC         2
 #define CHANNEL_ERROR        3
@@ -120,13 +120,13 @@ enum _ReqType {
 #define F13_CLIENT_REQ_SAVED_LIST         0x05
 #define F13_SERVER_SAVED_LIST             0x06
 #define F13_CLIENT_RDY_TO_USE_LIST        0x07
-#define F13_CLIENT_ADD_TO_LIST            0x08
-#define F13_CLIENT_UPDATE_LIST            0x09
-#define F13_CLIENT_REMOVE_FROM_LIST       0x0A
+#define F13_BOTH_ADD_TO_LIST              0x08
+#define F13_BOTH_UPDATE_LIST              0x09
+#define F13_BOTH_REMOVE_FROM_LIST         0x0A
 #define F13_SERVER_ACK                    0x0E
 #define F13_SERVER_LIST_NO_CHANGE         0x0F
-#define F13_CLIENT_START_MOD_LIST         0x11
-#define F13_CLIENT_END_MOD_LIST           0x12
+#define F13_BOTH_START_MOD_LIST           0x11
+#define F13_BOTH_END_MOD_LIST             0x12
 #define F13_CLIENT_AUTH_REQUEST_1         0x14
 #define F13_CLIENT_AUTH_REQUEST_2         0x18
 #define F13_SERVER_AUTH_REQUEST           0x19
@@ -180,7 +180,7 @@ struct _V7Packet {
   V7Connection *conn;
   BYTE channel;
   WORD len;
-  BYTE *data;
+  V7Buffer *buf;
 };
 
 struct _TLVstack {
@@ -192,7 +192,7 @@ struct _TLVstack {
 struct _TLV {
   WORD type;
   WORD len;
-  BYTE *value;
+  V7Buffer *buf;
 };
 
 struct _Snac {
@@ -201,8 +201,8 @@ struct _Snac {
   WORD  type;
   BYTE  flags[2];
   DWORD reqid;
-  BYTE *data;
   int   datalen;
+  V7Buffer *buf;
 };
 
 struct _Request {
@@ -237,13 +237,22 @@ struct _RateLimitedResendData {
 gboolean  flap_send(V7Connection *conn, BYTE flap_channel, const gchar *data,
                     WORD len);
 V7Packet *read_flap(V7Connection *conn);
+void      free_flap(V7Packet *packet);
 Snac     *read_snac(const V7Packet *packet);
+void 	  free_snac (Snac *snac);
 
 DWORD      snac_send(V7Connection *conn, const gchar *data, WORD len, 
                    WORD family, WORD subtype, BYTE flags[2], DWORD reqid);
 TLV       *new_tlv(const BYTE *place);
-TLV       *new_tlv_check(const BYTE *place, int len);
-void       delete_tlv (TLV *tlv);
+void       free_tlv (TLV *tlv);
+TLV 	  *_read_tlv (V7Buffer *buf);
+
+#define read_tlv(buf, out_err) ( { \
+  TLV *mytlv = _read_tlv(buf);     \
+  if (!mytlv)                      \
+    goto out_err;                  \
+  mytlv; } )
+
  
 
 void        display_tlv(const TLV *tlv);
