@@ -180,9 +180,7 @@ gboolean v7_newuser_handler (GIOChannel *iochannel, GIOCondition condition,
   
   if (packet->channel == 1 &&
       packet->len == 4  &&
-      packet->data[0] == packet->data[1] == packet->data[2] == 0 &&
-      packet->data[3] == 1) {
-    
+      !strncmp(packet->buf->here, "\0\0\0\x1", 4)) {
     const gchar buffer[4] = "\0\0\0\01";
     const gchar buffer2[44] = "\0\x01\0\0" "\0\0\0\0" "\x28\0\x03\0" "\0\0\0\0"
       "\0\0\0\0" "\x03\x46\0\0" "\x03\x46\0\0" "\0\0\0\0" "\0\0\0\0"
@@ -215,7 +213,10 @@ gboolean v7_newuser_handler (GIOChannel *iochannel, GIOCondition condition,
     if (snac->family == FAMILY_17_NEW_USER &&
         snac->type == F17_SERVER_ACK_NEW_USER ) {
 
-      our_info->uin = g_strdup_printf ("%d", Chars_2_DW(snac->data+46));
+      v7_buffer_skip(snac->buf, 46, out_err);
+
+      our_info->uin = g_strdup_printf ("%d", 
+          v7_buffer_get_dw_le(snac->buf, out_err));
       passwd = conn->cookie;
 
       g_io_channel_shutdown(conn->iochannel, TRUE, NULL);
@@ -231,7 +232,7 @@ gboolean v7_newuser_handler (GIOChannel *iochannel, GIOCondition condition,
     } else if (snac->family == FAMILY_17_NEW_USER &&
 	       snac->type == F17_BOTH_ERROR ) {
       GtkWidget *errordialog;
-      WORD error = CharsBE_2_Word(snac->data);
+      WORD error = v7_buffer_get_w_be (snac->buf, out_err);
 
       g_source_remove(conn->in_watch);
       g_io_channel_shutdown(conn->iochannel, TRUE, NULL);
@@ -241,12 +242,11 @@ gboolean v7_newuser_handler (GIOChannel *iochannel, GIOCondition condition,
       gnomeicu_spinner_stop();
 
       errordialog = gtk_message_dialog_new(GTK_WINDOW (MainData->window),
-					   GTK_DIALOG_DESTROY_WITH_PARENT |
-					   GTK_DIALOG_MODAL,
-					   GTK_MESSAGE_ERROR,
-					   GTK_BUTTONS_OK,
-					   _("The ICQ server does not allow you "
-					     "to create a new user\nExiting GnomeICU\n%s"), v7_get_error_message(error));
+          GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
+          GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+          _("The ICQ server does not allow you "
+              "to create a new user\nExiting GnomeICU\n%s"), 
+          v7_get_error_message(error));
 
       gtk_dialog_run(GTK_DIALOG(errordialog));
       gtk_main_quit();
@@ -260,5 +260,9 @@ gboolean v7_newuser_handler (GIOChannel *iochannel, GIOCondition condition,
   }  
   
   return TRUE;
+
+ out_err:
+  g_warning("Badly formed packet discarded");
+  return TRUE;
 }
 
