@@ -192,7 +192,7 @@ void v7_setstatus2(V7Connection *conn, DWORD newstatus)
     IP to zero
   */
     
-  DW_2_IP(directconnectioninfo, our_ip);
+  DW_2_CharsBE(directconnectioninfo, our_ip);
   DW_2_CharsBE(directconnectioninfo+4, our_port);
 
   directconnectioninfo[8] = 4; /* is 1 is firewall -- 4 is normal*/
@@ -617,9 +617,14 @@ void v7_send_file_msg2(V7Connection *conn, UIN_T uin, const gchar *msg,
   else
     add_tlv(middletlvs, 0x0A, "\x00\x02", 2);
   add_tlv(middletlvs, 0x0F, NULL, 0);
-  //add_tlv_dw_be(middletlvs, 0x03, our_ip);
-  add_tlv(middletlvs, 0x03, "\xa1\xb8\xa5\x2a", 4);
+  add_tlv(middletlvs, 0x0E, "en", 2);
+  
+  add_tlv_dw_be(middletlvs, 0x02, our_ip);; /* proxy ip */
+  add_tlv_dw_be(middletlvs, 0x16, ~our_ip);; /* proxy ip check*/
+  add_tlv_dw_be(middletlvs, 0x03, our_ip);
+  //add_tlv(middletlvs, 0x03, "\xa1\xb8\xa5\x2a", 4);
   add_tlv_w_be(middletlvs, 0x05, port);  /* port */
+  add_tlv_w_be(middletlvs, 0x17, ~port);  /* port check */
 
   innertlvs = new_tlvstack("\x1B\0", 2);
   
