@@ -43,11 +43,17 @@
 /*** enum and structs ***/
 
 typedef enum {
-  SNAC13_NONE = 0,
-  SNAC13_ADD_USER_NO_AUTH = 1 << 0,
-  SNAC13_ADD_USER_AUTH = 1 << 1,
-  SNAC13_REMOVE_USER = 1 << 2,
-  SNAC13_UPDATE_GROUP = 1 << 3,
+  SNAC13_NONE,
+  SNAC13_ADD_USER_NO_AUTH,
+  SNAC13_ADD_USER_AUTH,
+  SNAC13_REMOVE_USER,
+  SNAC13_UPDATE_GROUP,
+  SNAC13_ADD_VISIBLE,
+  SNAC13_REMOVE_VISIBLE,
+  SNAC13_ADD_INVISIBLE,
+  SNAC13_REMOVE_INVISIBLE,
+  SNAC13_ADD_IGNORE,
+  SNAC13_REMOVE_IGNORE
 } Snac13State;
 
 /* structure holding infos of the current state (for snac family 0x13 only)
@@ -65,7 +71,7 @@ struct _snac13_state {
   gchar *nick;
 
   guint gid, uid;
-  guint old_gid, old_uid; /* for change group */
+  guint new_gid; /* for change group */
   gboolean with_grant; /* whether send with a auth grant when adding new user */
 };
 
@@ -149,14 +155,15 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
   static gint group_seen = 0, uin_seen = 0;
   static gboolean done_reading_list = FALSE;
   static guint timer_handle = 0;
-  gchar *here = snac->data;
   gchar *xml_str = NULL; /* used to save the BWS string on each record */
   gint rec_count = 0; /* number of contact list record in current snac */
   gint i;
   gint len_str, gid, uid;
-  TLV *tlv;
+  TLV *tlv = NULL;
   guint32 timestamp;
   GSList *contact;
+  gchar *tmp;
+  TLV *tlv2 = NULL;
 
   Current_Status = STATUS_ONLINE;
 
@@ -170,14 +177,9 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
     need_reset = TRUE;
   }
 
-  /* with this flag, we have to skip 8 bytes first */
-  if (snac->flags[0] && 0x80)
-    here += 8;
+  v7_buffer_skip(snac->buf, 2, out_err);
 
-  here += 2;
-
-  rec_count = *here;
-  here++;
+  rec_count = v7_buffer_get_c(snac->buf, out_err);
 
   total_record += rec_count;
 
@@ -194,29 +196,27 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
   for (i = 0; i < rec_count; i++) {
     /* read the BWS string (Group name, UIN for icq, or AIM name) on each CL
        record */
-    len_str = CharsBE_2_Word (here);
-    here += 2;
+    len_str = v7_buffer_get_w_be(snac->buf, out_err);
     if (len_str != 0) {
-      xml_str = g_markup_escape_text (here, len_str);
+      tmp = v7_buffer_get(snac->buf, len_str);
+      if (!tmp)
+	goto out_err;
+      xml_str = g_markup_escape_text (tmp, len_str);
+      tmp = NULL;
       if (!xml_str) {
         g_warning ("%s %s\n", "v7snac13.c: unable to allocate space for nickname", "(xml_str)");
         break;
       }
-      here += len_str;
     }
 
     /* read group-id and uin-id */
-    gid = CharsBE_2_Word (here);
-    here += 2;
-    uid = CharsBE_2_Word (here);
-    here += 2;
+    gid = v7_buffer_get_w_be(snac->buf, out_err);
+    uid = v7_buffer_get_w_be(snac->buf, out_err);
 
     /* read the TLV, find out the type */
-    tlv = new_tlv (here);
+    tlv = read_tlv (snac->buf, out_err);
 
     switch (tlv->type) {
-      TLV *tlv2;
-      gint tlv_read; /* bytes read inside current tlv */
 
     case 0:  /* TLV 0: nickname, for each user */
       if (gid == 0) {
@@ -235,13 +235,11 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
         contact = Add_User (xml_str, NULL, TRUE);
       }
 
-      tlv_read = 0;
-      while (tlv_read < tlv->len) {
-        tlv2 = new_tlv (tlv->value + tlv_read);
+      while (tlv2 = read_tlv (tlv->buf, over)) {
         switch (tlv2->type) {
         case 0x131: /* nickname */
           g_free(kontakt->nick);
-          kontakt->nick = g_strdup (tlv2->value);
+	  kontakt->nick = v7_buffer_get_string(tlv2->buf, tlv2->len, out_err);
           break;
         case 0x66: /* with auth */
           kontakt->wait_auth = TRUE;
@@ -252,15 +250,19 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
         case 0x145: /* a message timestamp from icqlite */
 	case 0x6d: /* Unknown tlv.. comes from Mark (Mac ICQ? Gaim? Other) */
           break;
+	case 0x15c: /* Unknown, but related to the ICQ-MDIR stuff */
+	case 0x15d: /*  same as previous  */
+	  break;
         default:
           g_warning ("Unknown tlv type (0x%x) inside type 0", tlv2->type);
 	  packet_print_v7_snac(snac);
           break;
         }
 
-        tlv_read += TLV_HEADER + tlv2->len;
-        delete_tlv (tlv2);
+        free_tlv (tlv2);
+	tlv2 = NULL;
       }
+    over:
 
       kontakt->uid = uid;
       kontakt->gid = gid;
@@ -283,7 +285,7 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
         break;
       }
 
-      tlv2 = new_tlv (tlv->value);
+      tlv2 = read_tlv (tlv->buf, out_err);
       if (tlv2->type != 0xC8) {
         g_warning ("expecting TLV(C8): got TLV(0x%x).",tlv2->type);
       }
@@ -295,7 +297,8 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
         group_count = tlv2->len / 2;
         /* g_print ("group_count: %d\n",group_count); */
       }
-      delete_tlv (tlv2);
+      free_tlv (tlv2);
+      tlv2 = NULL;
       break;
     case 2:  /* zero length; vis to uin */
       if ( (contact = Find_User (xml_str)) == NULL ) {
@@ -312,18 +315,19 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
       kontakt->invis_list = TRUE;
       break;
     case 4:  /* last online status (invis or not invis) */
-      tlv2 = new_tlv (tlv->value);
+      tlv2 = read_tlv (tlv->buf, out_err);
       if (tlv2->type != 0xCA) {
         g_warning ("expecting TLV(CA) inside TLV(4): got TLV(0x%x).",tlv2->type);
       } else {
         status_uid = uid;
-        if (*(tlv2->value) == 0x03) {
+        if (v7_buffer_get_c(tlv2->buf, out_err) == 0x03) {
           if (preset_status != STATUS_INVISIBLE)
             Current_Status = STATUS_INVISIBLE;
         } else
           Current_Status = preset_status;
       }
-      delete_tlv (tlv2);
+      free_tlv (tlv2);
+      tlv2 = NULL;
       break;
     case 9:  /* unknown meaning, ignore */
       break;
@@ -351,6 +355,9 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
       break;
     case 0x1d: /* Unknown emnpty */
       break;
+    case 0x20: /* Uknown is also 0x20 bytes long and 
+		* is associated with ICQ-MDIR ?? */
+      break;
     default:
       g_warning ("Unknown TLV from server contact list: type 0x%x. It also "
                  "contains this string \"%s\".\n\n"
@@ -361,15 +368,14 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
       break;
     }
 
-    here += TLV_HEADER + tlv->len;
-
     g_free (xml_str);
     xml_str = NULL;
-    delete_tlv (tlv);
+    free_tlv (tlv);
+    tlv = NULL;
   } /* end for(rec_count) */
 
   /* read the 4 bytes timestamp at the end of the packet */
-  timestamp = CharsBE_2_DW (here);
+  timestamp = v7_buffer_get_dw_be(snac->buf, out_err);
 
   if ( (group_seen == group_count && uin_seen == uin_count) ||
        timestamp != 0 ) {
@@ -418,6 +424,15 @@ v7_read_contacts_list (Snac *snac, V7Connection *conn)
 
   if (done_reading_list)
     v7_got_contact_list (conn);
+
+  return;
+
+ out_err:
+  g_warning("Error parsing packet\n");
+
+  g_free(tlv);
+  g_free(tlv2);
+
 }
 
 gboolean
@@ -453,10 +468,10 @@ v7_begin_CL_edit (V7Connection *conn, gboolean migrate)
 
   if (migrate)
     snac_send (conn, data, 4, FAMILY_13_SAVED_LIST,
-               F13_CLIENT_START_MOD_LIST, NULL, ANY_ID);
+               F13_BOTH_START_MOD_LIST, NULL, ANY_ID);
   else
     snac_send (conn, NULL, 0, FAMILY_13_SAVED_LIST,
-               F13_CLIENT_START_MOD_LIST, NULL, ANY_ID);
+               F13_BOTH_START_MOD_LIST, NULL, ANY_ID);
 
 }
 
@@ -468,7 +483,7 @@ void
 v7_end_CL_edit (V7Connection *conn)
 {
   snac_send (conn, NULL, 0, FAMILY_13_SAVED_LIST,
-             F13_CLIENT_END_MOD_LIST, NULL, ANY_ID);
+             F13_BOTH_END_MOD_LIST, NULL, ANY_ID);
 }
 
 
@@ -638,8 +653,11 @@ v7_addto_contacts_list (V7Connection *conn, UIN_T uin, const gchar *nick,
   if (snac13_state.state != SNAC13_ADD_USER_AUTH &&
       snac13_state.state != SNAC13_ADD_USER_NO_AUTH)
     return 0;
-
-  v7_begin_CL_edit (conn, FALSE);
+  
+  if (!snac13_state.change_grp) {
+    snac13_state.change_grp = FALSE;
+    v7_begin_CL_edit (conn, FALSE);
+  }
 
   /* generate a new uid for this new user */
   uid = contact_gen_uid ();
@@ -679,8 +697,8 @@ v7_send_grant_auth (V7Connection *conn, UIN_T uin)
 void
 v7_snac13_check_srv_ack (V7Connection *conn, Snac *snac)
 {
-  gchar *here = snac->data;
-  gchar state = 0;
+  WORD state = 0;
+  BYTE smallstate;
 
   GSList *contact;
   Contact_Member *contactdata;
@@ -690,14 +708,13 @@ v7_snac13_check_srv_ack (V7Connection *conn, Snac *snac)
   g_print("v7_snac13_check_srv_ack\n");
 #endif
 
-  /* with this flag, we have to skip 8 bytes first */
-  if (snac->flags[0] && 0x80)
-    here += 8;
+  g_print("Current state is %d\n", snac13_state.state);
 
-  /* read the last byte */
-  state = *(here + 1);
+  /* read the status */
+  state = v7_buffer_get_w_be(snac->buf, out_err);
+  smallstate = state & 0xFF;
 
-  if ((state & 0xFF) != 0x0E) { /* no error */
+  if (smallstate == 0x00) { /* no error */
     switch (snac13_state.state) {
     case SNAC13_ADD_USER_AUTH:
     case SNAC13_ADD_USER_NO_AUTH:
@@ -711,8 +728,6 @@ v7_snac13_check_srv_ack (V7Connection *conn, Snac *snac)
       } else {
         contactdata = contact->data;
       }
-      if (contact)
-        gnomeicu_tree_user_remove (contactdata);
 
       g_free(contactdata->uin);
       contactdata->uin = g_strdup (snac13_state.uin);
@@ -738,21 +753,39 @@ v7_snac13_check_srv_ack (V7Connection *conn, Snac *snac)
 
       /* refresh the gui */
 
-      gnomeicu_tree_user_add (contactdata);
-      if (contactdata->status != STATUS_OFFLINE)
-        gnomeicu_tree_user_online (contactdata);
+      if (contact)
+	gnomeicu_tree_user_update (contactdata);
+      else
+	gnomeicu_tree_user_add (contactdata);
 
       nick = contactdata->nick;
       break;
     case SNAC13_UPDATE_GROUP:
+      g_print("We have a update group success\n");
       if (snac13_state.change_grp) {
+	g_print("We have a change group for %s %s\n", snac13_state.uin, snac13_state.nick);
+	guint uid;
+	UIN_T tmpuin;
+	gchar *tmpnick;
+
+	tmpuin = g_strdup(snac13_state.uin);
+	tmpnick = g_strdup(snac13_state.nick);
+
         /* if we are changing group, we start the remove contact here */
         snac13_state.state = SNAC13_NONE;
-        snac13_state.change_grp = FALSE;
-        v7_remove_contact (conn, snac13_state.uin, nick,
-                           snac13_state.old_gid, snac13_state.old_uid, FALSE);
+
+	uid = v7_try_add_uin (conn, tmpuin, tmpnick, 
+			      snac13_state.new_gid, FALSE);
+
+	g_free(tmpuin);
+	g_free(tmpnick);
+
+	user_group_changed(snac13_state.uin, snac13_state.new_gid, uid);
+	
       } else {
         /* just finish up, clear the state */
+	v7_end_CL_edit (conn);
+
         snac13_state.state = SNAC13_NONE;
       }
       break;
@@ -760,33 +793,185 @@ v7_snac13_check_srv_ack (V7Connection *conn, Snac *snac)
       /* user already removed in the local copy */
       /* user removal successful, update group */
       v7_update_group_info (conn, snac13_state.gid);
-      v7_end_CL_edit (conn);
 
+      if (!snac13_state.change_grp) {
+	v7_end_CL_edit (conn);
+      }
+      break;
+    case SNAC13_ADD_VISIBLE:
+      if ( (contact = Find_User (snac13_state.uin))) {
+	contactdata = contact->data;
+	contactdata->vis_list = 1;
+	contactdata->vislist_uid = snac13_state.uid;
+	gnomeicu_tree_user_update (contactdata);
+	Save_RC();
+      }
       snac13_state.state = SNAC13_NONE;
       break;
-   }
-  } else { /* error */
-    switch (snac13_state.state) {
-    case SNAC13_ADD_USER_NO_AUTH:
-      /* add user with no auth request unsuccessful, need to send auth req */
+    case SNAC13_REMOVE_VISIBLE:
+      if ( (contact = Find_User (snac13_state.uin))) {
+	contactdata = contact->data;
+	contactdata->vis_list = 0;
+	contactdata->vislist_uid = 0;
+	gnomeicu_tree_user_update (contactdata);
+	Save_RC();
+      }
+      snac13_state.state = SNAC13_NONE;
+      break;
+    case SNAC13_ADD_INVISIBLE:
+      if ( (contact = Find_User (snac13_state.uin))) {
+	contactdata = contact->data;
+	contactdata->invis_list = 1;
+	contactdata->invlist_uid = snac13_state.uid;
+	gnomeicu_tree_user_update (contactdata);
+	Save_RC();
+      }
+      snac13_state.state = SNAC13_NONE;
+      break;
+    case SNAC13_REMOVE_INVISIBLE:
+      if ( (contact = Find_User (snac13_state.uin))) {
+	contactdata = contact->data;
+	contactdata->invis_list = 0;
+	contactdata->invlist_uid = 0;
+	gnomeicu_tree_user_update (contactdata);
+	Save_RC();
+      }
+      snac13_state.state = SNAC13_NONE;
+      break;
+    case SNAC13_ADD_IGNORE:
+      if ( (contact = Find_User (snac13_state.uin))) {
+	contactdata = contact->data;
+	contactdata->ignore_list = 1;
+	contactdata->ignorelist_uid = snac13_state.uid;
+	gnomeicu_tree_user_update (contactdata);
+	Save_RC();
+      }
+      snac13_state.state = SNAC13_NONE;
+      break;
+    case SNAC13_REMOVE_IGNORE:
+      if ( (contact = Find_User (snac13_state.uin))) {
+	contactdata = contact->data;
+	contactdata->ignore_list = 0;
+	contactdata->ignorelist_uid = 0;
+	gnomeicu_tree_user_update (contactdata);
+	Save_RC();
+      }
+      snac13_state.state = SNAC13_NONE;
+      break;
+    default:
+      snac13_state.state = SNAC13_NONE;
+      break;
+
+    }
+    return;
+  } 
+
+  
+  /* 
+   * Handled error 
+   */
+  switch (snac13_state.state) {
+  case SNAC13_ADD_USER_NO_AUTH:
+    if (smallstate == 0x0E) { /* error: requires auth */
       v7_end_CL_edit (conn);
       auth_request_msg_box (snac13_state.nick, snac13_state.uin);
-      snac13_state.state = SNAC13_NONE;
-      break;
-    case SNAC13_ADD_USER_AUTH:
-      g_warning ("User adding failed: uin(%s) ", snac13_state.uin);
-      snac13_state.state = SNAC13_NONE;
-      break;
-    case SNAC13_REMOVE_USER:
-      g_warning ("User removal failed: uin(%s)", snac13_state.uin);
-      snac13_state.state = SNAC13_NONE;
-      break;
-    case SNAC13_UPDATE_GROUP:
-      g_warning ("Update group failed: uin(%s)", snac13_state.uin);
-      snac13_state.state = SNAC13_NONE;
-      break;
+      return;
     }
+    break;
+  case SNAC13_REMOVE_USER:
+    /* Trying to change user to another group, but he wasn't in the list */
+    if (snac13_state.change_grp && smallstate == 0x02) {
+      guint uid;
+      UIN_T tmpuin;
+      gchar *tmpnick;
+
+      //v7_end_CL_edit (conn);
+
+      /* if we are changing group, we start the remove contact here */
+      snac13_state.state = SNAC13_NONE;
+      snac13_state.change_grp = FALSE;
+
+      g_print("Remove failed, adding UIN: %s Nick: %s\n", snac13_state.uin, snac13_state.nick);
+
+      tmpuin = g_strdup(snac13_state.uin);
+      tmpnick = g_strdup(snac13_state.nick);
+
+      uid = v7_try_add_uin (conn, tmpuin, tmpnick, 
+			    snac13_state.new_gid, FALSE);
+
+      g_free(tmpuin);
+      g_free(tmpnick);
+
+      user_group_changed(snac13_state.uin, snac13_state.new_gid, uid);
+
+      return;
+    }
+    break;
+      default:
+    break;
   }
+  
+  /* 
+   * Other errors fall through)
+   */
+
+  switch (snac13_state.state) {
+  case SNAC13_ADD_USER_NO_AUTH:
+    /* add user with no auth request unsuccessful, need to send auth req */
+    g_warning ("User adding failed: uin(%s) error:0x%x", snac13_state.uin,
+	       state);
+    snac13_state.state = SNAC13_NONE;
+    break;
+  case SNAC13_ADD_USER_AUTH:
+    g_warning ("User adding failed: uin(%s) error:0x%x", snac13_state.uin,
+	       state);
+    break;
+  case SNAC13_REMOVE_USER:
+    g_warning ("User removal failed: uin(%s) error:0x%x", snac13_state.uin,
+	       state);
+    snac13_state.state = SNAC13_NONE;
+    break;
+  case SNAC13_UPDATE_GROUP:
+    g_warning ("Update group failed: uin(%s) error:0x%x", snac13_state.uin,
+	       state);
+    snac13_state.state = SNAC13_NONE;
+    break;
+  case SNAC13_ADD_VISIBLE:
+    g_warning ("Adding to visible failed: uin(%s) error:0x%x", snac13_state.uin,
+	       state);
+    snac13_state.state = SNAC13_NONE;
+    break;
+  case SNAC13_REMOVE_VISIBLE:
+    g_warning ("Removing from visible failed: uin(%s) error:0x%x", 
+	       snac13_state.uin, state);
+    snac13_state.state = SNAC13_NONE;
+    break;
+  case SNAC13_ADD_INVISIBLE:
+    g_warning ("Adding to invisible failed: uin(%s) error:0x%x", 
+	       snac13_state.uin, state);
+    snac13_state.state = SNAC13_NONE;
+    break;
+  case SNAC13_REMOVE_INVISIBLE:
+    g_warning ("Removing from invisible failed: uin(%s) error:0x%x", 
+	       snac13_state.uin, state);
+    snac13_state.state = SNAC13_NONE;
+    break;
+  case SNAC13_ADD_IGNORE:
+    g_warning ("Adding to ignore failed: uin(%s) error:0x%x", snac13_state.uin,
+	       state);
+    snac13_state.state = SNAC13_NONE;
+    break;
+  case SNAC13_REMOVE_IGNORE:
+    snac13_state.state = SNAC13_NONE;
+    g_warning ("Removing from ignore failed: uin(%s) error:0x%x", 
+	       snac13_state.uin, state);
+    break;
+
+  }
+
+  return;
+ out_err:
+  g_warning("%s: Error parsing packet\n", __FUNCTION__);
 } /* end void v7_snac13_check_srv_ack (Snac *snac) */
 
 
@@ -923,7 +1108,9 @@ v7_remove_contact (V7Connection *conn, UIN_T uin, const gchar *nick,
   snac13_state.gid = gid;
   snac13_state.uid = uid;
   g_free (snac13_state.nick);
-  snac13_state.nick = g_strdup(nick);
+  snac13_state.nick = g_strdup (nick);
+  g_free (snac13_state.uin);
+  snac13_state.uin = g_strdup (uin);
 
   tlvs = new_tlvstack (NULL, 0);
 
@@ -939,32 +1126,27 @@ v7_remove_contact (V7Connection *conn, UIN_T uin, const gchar *nick,
 void
 v7_recv_auth_request (Snac *snac)
 {
-  gchar *here = snac->data;
   UIN_T uin = NULL;
   gint str_len;
-  gchar *str;
+  gchar *str = NULL;
 
 #ifdef TRACE_FUNCTION
   g_print("v7_recv_auth_request\n");
 #endif
 
-  /* with this flag, we have to skip 8 bytes first */
-  if (snac->flags[0] && 0x80)
-    here += 8;
-
   /* read requester uin */
-  uin = g_strndup (here+1, here[0]);
-  here = here + here[0] + 1;
+  uin = v7_buffer_get_uin(snac->buf, out_err);
 
   /* read request msg length */
-  str_len = CharsBE_2_Word (here);
-  here += 2;
+  str_len = v7_buffer_get_w_be(snac->buf, out_err);
 
   /* read the request msg */
-  str = g_strndup (here, str_len);
+  str = v7_buffer_get_string(snac->buf, str_len, out_err);
 
   /* got all the info, now call the client auth handler */
   authorization_request(uin, str, time(NULL));
+
+ out_err:
   g_free (str);
 }
 
@@ -1000,27 +1182,20 @@ v7_grant_auth_request (V7Connection *conn, UIN_T uin)
 void
 v7_user_grant_auth (Snac *snac)
 {
-  gchar *here = snac->data;
-  UIN_T uin;
+  UIN_T uin = NULL;
   int flag;
   char *reason = NULL, *r2=NULL;
-  int strlen;
-
-  /* with this flag, we have to skip 8 bytes first */
-  if (snac->flags[0] && 0x80)
-    here += 8;
+  int str_len;
 
   /* read sender uin */
-  uin = g_strndup (here+1, here[0]);
-  here = here + here[0] + 1;
+  uin = v7_buffer_get_uin(snac->buf, out_err);
 
-  flag = here[0];
-  here++;
+  flag = v7_buffer_get_c(snac->buf, out_err);
 
-  strlen = CharsBE_2_Word(here);
-  here += 2;
-  if (strlen) {
-    r2 = g_strndup(here, strlen);
+  str_len = v7_buffer_get_w_be(snac->buf, out_err);
+
+  if (str_len) {
+    r2 = v7_buffer_get_string(snac->buf, str_len, out_err);
     if (r2) {
       reason = convert_to_utf8(r2);
       g_free(r2);
@@ -1029,6 +1204,7 @@ v7_user_grant_auth (Snac *snac)
 
   auth_reply(uin, flag, reason, time(NULL));
 
+ out_err:
   g_free (uin);
   g_free (reason);
 }
@@ -1039,21 +1215,17 @@ v7_user_grant_auth (Snac *snac)
 void
 v7_recv_added_you (Snac *snac)
 {
-  UIN_T uin;
+  UIN_T uin = NULL;
   time_t msg_time;
-  gchar *here = snac->data;
-
-  /* with this flag, we have to skip 8 bytes first */
-  if (snac->flags[0] && 0x80)
-    here += 8;
 
   /* read sender uin */
-  uin = g_strndup (here+1, here[0]);
+  uin = v7_buffer_get_uin(snac->buf, out_err);
 
   time(&msg_time);
 
   user_added_you(uin, msg_time);
 
+ out_err:
   g_free (uin);
 }
 
@@ -1069,9 +1241,14 @@ v7_visible (V7Connection *conn, UIN_T uin, WORD luid, gboolean add)
 
   snac13_construct_visible (tlvs, uin, luid);
 
+  snac13_state.uin = uin;
+  snac13_state.uid = luid;
+
   if (add) {
+    snac13_state.state = SNAC13_ADD_VISIBLE;
     snac13_send_add_to_list (conn, tlvs);
   } else {
+    snac13_state.state = SNAC13_REMOVE_VISIBLE;
     snac13_send_remove_from_list (conn, tlvs);
   }
 
@@ -1090,10 +1267,15 @@ v7_invisible (V7Connection *conn, UIN_T uin, WORD luid, gboolean add)
 
   snac13_construct_invisible (tlvs, uin, luid);
 
+  snac13_state.uin = uin;
+  snac13_state.uid = luid;
+
   if (add) {
+    snac13_state.state = SNAC13_ADD_INVISIBLE;
     snac13_send_add_to_list (conn, tlvs);
   } else {
-    snac13_send_remove_from_list (conn, tlvs);
+    snac13_state.state = SNAC13_REMOVE_INVISIBLE;
+   snac13_send_remove_from_list (conn, tlvs);
   }
 
   free_tlvstack (tlvs);
@@ -1111,9 +1293,14 @@ v7_ignore (V7Connection *conn, UIN_T uin, WORD luid, gboolean add)
 
   snac13_construct_ignore (tlvs, uin, luid);
 
+  snac13_state.uin = uin;
+  snac13_state.uid = luid;
+
   if (add) {
+    snac13_state.state =  SNAC13_ADD_IGNORE;
     snac13_send_add_to_list (conn, tlvs);
   } else {
+    snac13_state.state =  SNAC13_REMOVE_IGNORE;
     snac13_send_remove_from_list (conn, tlvs);
   }
 
@@ -1123,16 +1310,15 @@ v7_ignore (V7Connection *conn, UIN_T uin, WORD luid, gboolean add)
 /*
  * move user around groups
  */
-guint
+void
 v7_user_change_group (V7Connection *conn, Contact_Member *c,
                       WORD new_gid, const gchar *new_grpname)
 {
   snac13_state.change_grp = TRUE;
 
-  snac13_state.old_gid = c->gid;
-  snac13_state.old_uid = c->uid;
+  snac13_state.new_gid = new_gid;
 
-  return v7_try_add_uin (conn, c->uin, c->nick, new_gid, FALSE);
+  v7_remove_contact (conn, c->uin, c->nick, c->gid, c->uid, c->wait_auth);
 }
 
 void
@@ -1364,21 +1550,21 @@ void
 snac13_send_add_to_list (V7Connection *conn, const TLVstack *t)
 {
   snac_send (conn, t->beg, t->len, FAMILY_13_SAVED_LIST,
-             F13_CLIENT_ADD_TO_LIST, NULL, ANY_ID);
+             F13_BOTH_ADD_TO_LIST, NULL, ANY_ID);
 }
 
 void
 snac13_send_update_list (V7Connection *conn, const TLVstack *t)
 {
   snac_send (conn, t->beg, t->len, FAMILY_13_SAVED_LIST,
-             F13_CLIENT_UPDATE_LIST, NULL, ANY_ID);
+             F13_BOTH_UPDATE_LIST, NULL, ANY_ID);
 }
 
 void
 snac13_send_remove_from_list (V7Connection *conn, const TLVstack *t)
 {
   snac_send (conn, t->beg, t->len, FAMILY_13_SAVED_LIST,
-             F13_CLIENT_REMOVE_FROM_LIST, NULL, ANY_ID);
+             F13_BOTH_REMOVE_FROM_LIST, NULL, ANY_ID);
 }
 
 void
